@@ -13,10 +13,11 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
 */
 
+#include <kglobal.h>
 #include "ai88handler.h"
 
 AI88Handler::AI88Handler(AIParserBase *delegate){
@@ -91,7 +92,7 @@ bool AI88Handler::handleAIOperation (AIOperation op) {
       return true;
       break;
     case AIO_SetLineWidth :
-      fval = m_delegate->getDoubleValue();
+      fval = kMax(0.2, m_delegate->getDoubleValue()); // Use thinnest pen stroke possible for 0 (Rob)
       if (m_delegate->m_gstateHandler) m_delegate->m_gstateHandler->gotLineWidth (fval);
       return true;
       break;
@@ -405,7 +406,7 @@ void AI88Handler::_handleSetStrokeColorGray()
 void AI88Handler::_handleSetFillColorCustom()
 {
   double g = m_delegate->getDoubleValue();
-  const QString &name = m_delegate->getStringValue();
+  const QString name = m_delegate->getStringValue();
   double k = m_delegate->getDoubleValue();
   double y = m_delegate->getDoubleValue();
   double m = m_delegate->getDoubleValue();
@@ -550,7 +551,7 @@ void AI88Handler::_handleFontEncoding()
 void AI88Handler::_handleSetStrokeColorCustom()
 {
   double g = m_delegate->getDoubleValue();
-  const QString &name = m_delegate->getStringValue();
+  const QString name = m_delegate->getStringValue();
   double k = m_delegate->getDoubleValue();
   double y = m_delegate->getDoubleValue();
   double m = m_delegate->getDoubleValue();
