@@ -1,5 +1,3 @@
-//
-
 /*
    This file is part of the KDE project
    Copyright (C) 2001, 2002, 2004 Nicolas GOUTTE <goutte@kde.org>
@@ -16,8 +14,8 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
 */
 
 #include <qstring.h>
@@ -586,7 +584,7 @@ bool HtmlWorker::doOpenHead(void)
     *m_streamOut << (isXML()?" /":"") << ">\n" ;
 
     // Say who we are (with the CVS revision number) in case we have a bug in our filter output!
-    QString strVersion("$Revision: 396742 $");
+    QString strVersion("$Revision: 466447 $");
     // Eliminate the dollar signs
     //  (We don't want that the version number changes if the HTML file is itself put in a CVS storage.)
     *m_streamOut << "<meta name=\"Generator\" content=\"KWord HTML Export Filter Version"
