@@ -1,8 +1,6 @@
-// $Header: /home/kde/koffice/filters/kword/libexport/KWEFBaseWorker.h,v 1.20 2003/01/26 13:41:25 goutte Exp $
-
 /*
    This file is part of the KDE project
-   Copyright 2001, 2002, 2003 Nicolas GOUTTE <goutte@kde.org>
+   Copyright 2001, 2002, 2003, 2004 Nicolas GOUTTE <goutte@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -16,8 +14,8 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
 */
 
 #ifndef KWEF_BASEWORKER_H
@@ -27,10 +25,14 @@
 #include <qiodevice.h>
 
 #include <KWEFStructures.h>
+#include <koffice_export.h>
 
 class KWEFKWordLeader;
 
-class KWEFBaseWorker
+/**
+ * Base worker of the libexport system
+ */
+class KOFFICEFILTER_EXPORT KWEFBaseWorker
 {
     public:
         KWEFBaseWorker(void) : m_kwordLeader(NULL) {}
@@ -58,22 +60,28 @@ class KWEFBaseWorker
         virtual bool doFullParagraph(const QString& paraText, const LayoutData& layout,
             const ValueListFormatData& paraFormatDataList);
         virtual bool doFullPaperFormat (const int format,
-            const double width, const double height, const int orientation); // Like AbiWord's <papersize>
+            const double width, const double height, const int orientation); ///< Like AbiWord's \<papersize\>
         virtual bool doFullPaperBorders (const double top, const double left,
-            const double bottom, const double right); // Like KWord's <PAPERBORDERS>
+            const double bottom, const double right); ///< Like KWord's \<PAPERBORDERS\>
+        /**
+         * Other data of KWord's \<PAPER\> which are not in @see doFullPaperFormat
+         * @since 1.4
+         */
+        virtual bool doFullPaperFormatOther ( const int columns, const double columnspacing, const int numPages );
         virtual bool doPageInfo(const int headerType, const int footerType);
         virtual bool doHeader(const HeaderData& header);
         virtual bool doFooter(const FooterData& footer);
-        virtual bool doOpenHead (void); // Like HTML's <HEAD>
-        virtual bool doCloseHead (void); // Like HTML's </HEAD>
-        virtual bool doOpenBody (void); // Like HTML's <BODY>
-        virtual bool doCloseBody (void); // Like HTML's </BODY>
-        virtual bool doOpenStyles (void); // Like HTML's <style>
-        virtual bool doCloseStyles (void); // Like HTML's </style>
-        virtual bool doFullDefineStyle (LayoutData& layout); // Defines a single style
-        virtual bool doOpenSpellCheckIgnoreList (void); // like AbiWord's <ignorewords> and KWord's <SPELLCHECKIGNORELIST>
-        virtual bool doCloseSpellCheckIgnoreList (void); // like AbiWord's </ignorewords> and Kwords </SPELLCHECKIGNORELIST>
-        virtual bool doFullSpellCheckIgnoreWord (const QString& ignoreword); // like AbiWord's <iw> and Kwords </SPELLCHECKIGNOREWORD>
+        virtual bool doOpenHead (void); ///< Like HTML's \<HEAD\>
+        virtual bool doCloseHead (void); ///< Like HTML's \</HEAD\>
+        virtual bool doOpenBody (void); ///< Like HTML's \<BODY\>
+        virtual bool doCloseBody (void); ///< Like HTML's \</BODY\>
+        virtual bool doOpenStyles (void); ///< Like HTML's \<style\>
+        virtual bool doCloseStyles (void); ///< Like HTML's \</style\>
+        virtual bool doFullDefineStyle (LayoutData& layout); ///< Defines a single style
+        virtual bool doOpenSpellCheckIgnoreList (void); ///< like AbiWord's \<ignorewords\> and KWord's \<SPELLCHECKIGNORELIST\>
+        virtual bool doCloseSpellCheckIgnoreList (void); ///< like AbiWord's \</ignorewords\> and Kwords \</SPELLCHECKIGNORELIST\>
+        virtual bool doFullSpellCheckIgnoreWord (const QString& ignoreword); ///< like AbiWord's \<iw\> and Kwords \</SPELLCHECKIGNOREWORD\>
+        virtual bool doDeclareNonInlinedFramesets( QValueList<FrameAnchor>& pictureAnchors, QValueList<FrameAnchor>& tableAnchors ); ///< @since 1.4
     protected:
         KWEFKWordLeader* m_kwordLeader;
 };
