@@ -23,7 +23,7 @@ DESCRIPTION
 #include <pptdoc.h>
 #include <pptxml.h>
 #include <qobject.h>
-#include <koGlobal.h>
+#include <KoGlobal.h>
 
 const int PptXml::s_area = 30512;
 
