@@ -14,8 +14,8 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
 */
 
 #include <klocale.h>
@@ -47,8 +47,11 @@ VGroupCmd::execute()
 	VObjectListIterator itr( m_selection->objects() );
 	for ( ; itr.current() ; ++itr )
 	{
-		// TODO : remove from corresponding VLayer
-		document()->activeLayer()->take( *itr.current() );
+		// remove from corresponding parent
+		VGroup *parent = dynamic_cast<VGroup*>( itr.current()->parent() );
+		if( parent )
+			parent->take( *itr.current() );
+
 		m_group->append( itr.current() );
 	}
 
@@ -62,6 +65,9 @@ VGroupCmd::execute()
 void
 VGroupCmd::unexecute()
 {
+	if( ! m_group ) 
+		return;
+
 	document()->selection()->clear();
 
 	VObjectListIterator itr( m_group->objects() );
@@ -81,14 +87,14 @@ VGroupCmd::unexecute()
 		VObjectListIterator itr = m_selection->objects();
 
 		for ( ; itr.current() ; ++itr )
+		{
 			parent->append( itr.current() );
+		}
 
 		m_group->clear();
+		m_group->setState( VObject::deleted );
 	}
 	
-	delete m_group;
-	m_group = 0L;
-
 	setSuccess( false );
 }
 
