@@ -13,8 +13,8 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
 */
 
 
@@ -50,13 +50,11 @@ namespace KChart
 
 KChartConfigDialog::KChartConfigDialog( KChartParams* params,
 					QWidget* parent, int flags,
-					KoChart::Data *dat, 
-					KChartAuxiliary *aux ) :
+					KDChartTableData *dat ) :
     QTabDialog( parent, "Chart config dialog", true ),
     m_params( params ),
-    m_aux(aux),
 
-    m_datapage(0),
+    m_dataPage(0),
     m_subTypePage(0),
 
     _parameter3dpage(0),
@@ -76,11 +74,11 @@ KChartConfigDialog::KChartConfigDialog( KChartParams* params,
     // Geometry page
     //_geompage = new KChartGeometryConfigPage( this );
     //addTab( _geompage, i18n( "&Geometry" ) );
-    setCaption( i18n( "Chart Config Dialog" ) );
+    setCaption( i18n( "Chart Setup" ) );
 
     if (flags & KC_DATAFORMAT) {
-        m_datapage = new KChartDataConfigPage(m_params, this, dat, aux);
-        addTab( m_datapage, i18n( "&Data" ) );
+        m_dataPage = new KChartDataConfigPage(m_params, this, dat);
+        addTab( m_dataPage, i18n( "&Data" ) );
     }
     else if (flags & KC_SUBTYPE) {
         subtypePage();
@@ -107,24 +105,28 @@ KChartConfigDialog::KChartConfigDialog( KChartParams* params,
     }
     else if ( flags & KC_ALL ) {
 	// The data page
-        m_datapage = new KChartDataConfigPage(m_params, this, dat, aux);
-        addTab( m_datapage, i18n( "&Data" ) );
+        m_dataPage = new KChartDataConfigPage(m_params, this, dat);
+        addTab( m_dataPage, i18n( "&Data" ) );
 
 	// The subtype page
         subtypePage();
 
 	// The subtype configuration page (not for all types).
-        if ( m_params->chartType() == KDChartParams::Bar ) {
+        if ( m_params->chartType() == KChartParams::Bar ) {
             _parameter3dpage = new KChartParameter3dConfigPage(m_params,this );
             addTab( _parameter3dpage,i18n("Bar"));
         }
-#if 1	// Disabled due to bugs and all around uglyness.
-        else if ( m_params->chartType() == KDChartParams::Line) {
+        else if ( m_params->chartType() == KChartParams::Line) {
             _linepage3d= new KChartLine3dConfigPage(m_params,this);
             addTab( _linepage3d,i18n("Line"));
         }
+#if 0
+        else if ( m_params->chartType() == KChartParams::BarLines) {
+            m_barslinesPage = new KChartBarslinesConfigPage(m_params, this);
+            addTab( _linepage3d,i18n("Line"));
+        }
 #endif
-	else if ( m_params->chartType() == KDChartParams::Pie ) {
+	else if ( m_params->chartType() == KChartParams::Pie ) {
 
             _parameterpiepage = new KChartParameterPieConfigPage(m_params, 
 								 this );
@@ -135,7 +137,7 @@ KChartConfigDialog::KChartConfigDialog( KChartParams* params,
             addTab( _piepage, i18n( "&Piedata" ) );
 #endif
         }
-        else if ( m_params->chartType() == KDChartParams::Polar) {
+        else if ( m_params->chartType() == KChartParams::Polar) {
             _polarpage=new KChartParameterPolarConfigPage(m_params,this);
             addTab( _polarpage,i18n("&Polar"));
         }
@@ -150,8 +152,8 @@ KChartConfigDialog::KChartConfigDialog( KChartParams* params,
         addTab( m_legendPage,i18n("Legend"));
 
 	// Add axes page if applicable (all except Pie, Ring).
-        if ( m_params->chartType() != KDChartParams::Pie
-	     && m_params->chartType() != KDChartParams::Ring ) {
+        if ( m_params->chartType() != KChartParams::Pie
+	     && m_params->chartType() != KChartParams::Ring ) {
 
             m_axespage = new KChartParameterConfigPage(m_params,this );
             addTab( m_axespage, i18n( "&Axes" ) );
@@ -167,9 +169,9 @@ KChartConfigDialog::KChartConfigDialog( KChartParams* params,
 								   this );
         addTab( _backgroundpixpage, i18n( "&Background" ) );
 
-        if ( m_params->chartType() == KDChartParams::HiLo &&
-            ( m_params->hiLoChartSubType() == KDChartParams::HiLoClose ||
-              m_params->hiLoChartSubType() == KDChartParams::HiLoOpenClose ) ) {
+        if ( m_params->chartType() == KChartParams::HiLo &&
+            ( m_params->hiLoChartSubType() == KChartParams::HiLoClose ||
+              m_params->hiLoChartSubType() == KChartParams::HiLoOpenClose ) ) {
             // PENDING(kalle) Combo page needs to be redone completely.
             //         _hlcChart=new KChartComboPage(m_params,this);
 //         addTab( _hlcChart, i18n( "HLC Chart" ) );
@@ -197,15 +199,18 @@ KChartConfigDialog::KChartConfigDialog( KChartParams* params,
 void KChartConfigDialog::init()
 {
     // Data page
-    if (m_datapage)
-        m_datapage->init();
+    if (m_dataPage)
+        m_dataPage->init();
 
     // Color page
     if (_colorpage) {
         _colorpage->setLineColor( m_params->outlineDataColor() );
-        KDChartAxisParams leftparams( m_params->axisParams( KDChartAxisParams::AxisPosLeft ) );
-        KDChartAxisParams rightparams( m_params->axisParams( KDChartAxisParams::AxisPosRight ) );
-        KDChartAxisParams bottomparams( m_params->axisParams( KDChartAxisParams::AxisPosBottom ) );
+        KDChartAxisParams leftparams;
+        leftparams = m_params->axisParams( KDChartAxisParams::AxisPosLeft );
+        KDChartAxisParams rightparams;
+        rightparams = m_params->axisParams( KDChartAxisParams::AxisPosRight );
+        KDChartAxisParams bottomparams;
+        bottomparams = m_params->axisParams( KDChartAxisParams::AxisPosBottom );
         _colorpage->setGridColor( leftparams.axisGridColor() );
         _colorpage->setXTitleColor( m_params->axisTitleColor( KDChartAxisParams::AxisPosLeft ) );
         _colorpage->setYTitleColor( m_params->axisTitleColor( KDChartAxisParams::AxisPosBottom ) );
@@ -216,6 +221,16 @@ void KChartConfigDialog::init()
         _colorpage->setYLabelColor( leftparams.axisLabelsColor() );
 #if 0
         _colorpage->setYLabel2Color( rightparams.axisLabelsColor() );
+#endif
+        _colorpage->setXLineColor( bottomparams.axisLineColor() );
+        _colorpage->setYLineColor( leftparams.axisLineColor() );
+#if 0
+        _colorpage->setYLine2Color( rightparams.axisLineColor() );
+#endif
+        _colorpage->setXZeroLineColor( bottomparams.axisZeroLineColor() );
+        _colorpage->setYZeroLineColor( leftparams.axisZeroLineColor() );
+#if 0
+        _colorpage->setYZeroLine2Color( rightparams.axisZeroLineColor() );
 #endif
         // PENDING(kalle) Replace with KDChart equivalents
         //     _colorpage->setBackgroundColor( m_params->BGColor );
@@ -237,7 +252,7 @@ void KChartConfigDialog::init()
     if (_parameter3dpage)
         _parameter3dpage->init();
 
-    if ( _linepage3d && m_params->chartType() == KDChartParams::Line)
+    if ( _linepage3d && m_params->chartType() == KChartParams::Line)
         _linepage3d->init();
 
     if (_parameterfontpage)
@@ -276,8 +291,8 @@ void KChartConfigDialog::apply()
     // being used by the application.
 
     // Data page
-    if (m_datapage)
-        m_datapage->apply();
+    if (m_dataPage)
+        m_dataPage->apply();
 
     // color page
 
@@ -289,11 +304,15 @@ void KChartConfigDialog::apply()
 
     if (_colorpage) {
 
-        KDChartAxisParams leftparams = m_params->axisParams( KDChartAxisParams::AxisPosLeft );
+        KDChartAxisParams leftparams;
+        leftparams = m_params->axisParams( KDChartAxisParams::AxisPosLeft );
         leftparams.setAxisGridColor( _colorpage->gridColor() );
         m_params->setOutlineDataColor( _colorpage->lineColor() );
-        KDChartAxisParams rightparams = m_params->axisParams( KDChartAxisParams::AxisPosRight );
-        KDChartAxisParams bottomparams = m_params->axisParams( KDChartAxisParams::AxisPosBottom );
+
+        KDChartAxisParams rightparams;
+        rightparams = m_params->axisParams( KDChartAxisParams::AxisPosRight );
+        KDChartAxisParams bottomparams;
+        bottomparams = m_params->axisParams( KDChartAxisParams::AxisPosBottom );
         if( _colorpage->xTitleColor().isValid() )
             m_params->setAxisTitleColor( KDChartAxisParams::AxisPosBottom, _colorpage->xTitleColor() );
         else
@@ -308,11 +327,24 @@ void KChartConfigDialog::apply()
         else
             rightparams.setAxisLineColor( QColor() );
 #endif
+
         bottomparams.setAxisLabelsColor( _colorpage->xLabelColor() );
         leftparams.setAxisLabelsColor( _colorpage->yLabelColor() );
 #if 0
         rightparams.setAxisLabelsColor( _colorpage->yLabel2Color() );
 #endif
+
+        bottomparams.setAxisLineColor( _colorpage->xLineColor() );
+        leftparams.setAxisLineColor( _colorpage->yLineColor() );
+#if 0
+        rightparams.setAxisLineColor( _colorpage->yLine2Color() );
+#endif
+
+        bottomparams.setAxisZeroLineColor( _colorpage->xZeroLineColor() );
+        leftparams.setAxisZeroLineColor( _colorpage->yZeroLineColor() );
+#if 0
+        rightparams.setAxisZeroLineColor( _colorpage->yZeroLine2Color() );
+#endif
         m_params->setAxisParams( KDChartAxisParams::AxisPosBottom, bottomparams );
         m_params->setAxisParams( KDChartAxisParams::AxisPosLeft,   leftparams );
 #if 0
@@ -329,10 +361,10 @@ void KChartConfigDialog::apply()
     if (_piepage)
 	_piepage->apply();
 #endif
-    if( _parameter3dpage && m_params->chartType() == KDChartParams::Bar  )
+    if( _parameter3dpage && m_params->chartType() == KChartParams::Bar  )
         _parameter3dpage->apply();
 
-    if( _linepage3d && m_params->chartType() == KDChartParams::Line)
+    if( _linepage3d && m_params->chartType() == KChartParams::Line)
         _linepage3d->apply();
 
     if(_parameterfontpage)
@@ -344,9 +376,9 @@ void KChartConfigDialog::apply()
     if( m_subTypePage )
         m_subTypePage->apply();
 
-    if ( m_params->chartType() == KDChartParams::HiLo &&
-        ( m_params->hiLoChartSubType() == KDChartParams::HiLoClose ||
-          m_params->hiLoChartSubType() == KDChartParams::HiLoOpenClose ) )
+    if ( m_params->chartType() == KChartParams::HiLo &&
+        ( m_params->hiLoChartSubType() == KChartParams::HiLoClose ||
+          m_params->hiLoChartSubType() == KChartParams::HiLoOpenClose ) )
     {
         /* if( _hlcChart)
            _hlcChart->apply();*/
@@ -393,7 +425,7 @@ void KChartConfigDialog::subtypePage()
 	return;
         ; 
     }
-    addTab( m_subTypePage, i18n( "Chart &Subtype" ) );
+    addTab( m_subTypePage, i18n( "Chart &Sub-type" ) );
 }
 
 
