@@ -507,7 +507,7 @@ class KEXI_DB_EXPORT Field
 		 Every QueryAsterisk object returns true here,
 		 and every Field object returns false.
 		*/
-		inline bool isQueryAsterisk() const { return type() == Asterisk; }
+		bool isQueryAsterisk() const;
 		
 		/*! \return string for debugging purposes. */
 		virtual QString debugString() const;
@@ -570,6 +570,9 @@ class KEXI_DB_EXPORT Field
 		/*! @internal Used by constructors. */
 		void init();
 
+		//! \return a deep copy of this object. Used in @ref FieldList(const FieldList& fl).
+		virtual Field* copy() const;
+
 		FieldList *m_parent; //!< In most cases this points to a TableSchema 
 		                     //!< object that field is assigned.
 		QString m_name;
