@@ -1,5 +1,5 @@
 /* This file is part of the KDE project
-   Copyright (C) 2004-2006 Jaroslaw Staniek <js@iidea.pl>
+   Copyright (C) 2004-2007 Jaroslaw Staniek <js@iidea.pl>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -20,6 +20,7 @@
 #include "utils.h"
 #include "cursor.h"
 #include "drivermanager.h"
+#include "lookupfieldschema.h"
 
 #include <qmap.h>
 #include <qthread.h>
@@ -244,6 +245,15 @@ TableOrQuerySchema::TableOrQuerySchema(QuerySchema* query)
 		KexiDBWarn << "TableOrQuery(QuerySchema* query) : no query specified!" << endl;
 }
 
+uint TableOrQuerySchema::fieldCount() const
+{
+	if (m_table)
+		return m_table->fieldCount();
+	if (m_query)
+		return m_query->fieldsExpanded().size();
+	return 0;
+}
+
 const QueryColumnInfo::Vector TableOrQuerySchema::columns(bool unique)
 {
 	if (m_table)
@@ -480,6 +490,14 @@ void KexiDB::connectionTestDialog(QWidget* parent, const KexiDB::ConnectionData&
 	dlg.exec();
 }
 
+int KexiDB::rowCount(Connection &conn, const QString& sql)
+{
+	int count = -1; //will be changed only on success of querySingleNumber()
+	QString selectSql( QString::fromLatin1("SELECT COUNT() FROM (") + sql + ")" );
+	conn.querySingleNumber(selectSql, count);
+	return count;
+}
+
 int KexiDB::rowCount(const KexiDB::TableSchema& tableSchema)
 {
 //! @todo does not work with non-SQL data sources
@@ -505,7 +523,7 @@ int KexiDB::rowCount(KexiDB::QuerySchema& querySchema)
 	}
 	int count = -1; //will be changed only on success of querySingleNumber()
 	querySchema.connection()->querySingleNumber(
-		QString::fromLatin1("SELECT COUNT() FROM (") 
+		QString::fromLatin1("SELECT COUNT(*) FROM (") 
 		+ querySchema.connection()->selectStatement(querySchema) + ")",
 		count
 	);
@@ -589,7 +607,7 @@ QString KexiDB::formatNumberForVisibleDecimalPlaces(double value, int decimalPla
 {
 //! @todo round?
 	if (decimalPlaces < 0) {
-		QString s = QString::number(value, 'f', 10 /*reasonable precision*/);
+		QString s( QString::number(value, 'f', 10 /*reasonable precision*/));
 		uint i = s.length()-1;
 		while (i>0 && s[i]=='0')
 			i--;
@@ -740,9 +758,19 @@ QAsciiDict<char>* KexiDB_extendedProperties = 0;
 bool KexiDB::isExtendedTableFieldProperty( const QCString& propertyName )
 {
 	if (!KexiDB_extendedProperties) {
-		KexiDB_extendedPropertiesDeleter.setObject( KexiDB_extendedProperties, new QAsciiDict<char>(499) );
+		KexiDB_extendedPropertiesDeleter.setObject( KexiDB_extendedProperties, new QAsciiDict<char>(499, false) );
 #define ADD(name) KexiDB_extendedProperties->insert(name, (char*)1)
 		ADD("visibleDecimalPlaces");
+		ADD("rowSource");
+		ADD("rowSourceType");
+		ADD("rowSourceValues");
+		ADD("boundColumn");
+		ADD("visibleColumn");
+		ADD("columnWidths");
+		ADD("showColumnHeaders");
+		ADD("listRows");
+		ADD("limitToList");
+		ADD("displayWidget");
 #undef ADD
 	}
 	return KexiDB_extendedProperties->find( propertyName );
@@ -764,6 +792,7 @@ bool KexiDB::setFieldProperty( Field& field, const QCString& propertyName, const
 			field.method( ival ); \
 			return true; \
 		}
+
 	if (propertyName.isEmpty())
 		return false;
 
@@ -771,8 +800,28 @@ bool KexiDB::setFieldProperty( Field& field, const QCString& propertyName, const
 	if (KexiDB::isExtendedTableFieldProperty(propertyName)) {
 		//a little speedup: identify extended property in O(1)
 		if ( "visibleDecimalPlaces" == propertyName
-		  && KexiDB::supportsVisibleDecimalPlacesProperty(field.type()) )
+			&& KexiDB::supportsVisibleDecimalPlacesProperty(field.type()) )
+		{
 			GET_INT( setVisibleDecimalPlaces );
+		}
+		else {
+			if (!field.table()) {
+				KexiDBWarn << QString("KexiDB::setFieldProperty() Cannot set \"%1\" property - no table assinged for field!")
+					.arg(propertyName) << endl;
+			}
+			else {
+				LookupFieldSchema *lookup = field.table()->lookupFieldSchema(field);
+				const bool hasLookup = lookup != 0;
+				if (!hasLookup)
+					lookup = new LookupFieldSchema();
+				if (LookupFieldSchema::setProperty( *lookup, propertyName, value )) {
+					if (!hasLookup && lookup)
+						field.table()->setLookupFieldSchema( field.name(), lookup );
+					return true;
+				}
+				delete lookup;
+			}
+		}
 	}
 	else {//non-extended
 		if ( "type" == propertyName )
@@ -913,9 +962,10 @@ QDomElement KexiDB::saveBooleanElementToDom(QDomDocument& doc, QDomElement& pare
 {
 	QDomElement el( doc.createElement(elementName) );
 	parentEl.appendChild( el );
-	QDomElement boolEl( doc.createElement("bool") );
-	el.appendChild( boolEl );
-	boolEl.appendChild( doc.createTextNode( value ? "true" : "false" ) );
+	QDomElement numberEl( doc.createElement("bool") );
+	el.appendChild( numberEl );
+	numberEl.appendChild( doc.createTextNode( 
+		value ? QString::fromLatin1("true") : QString::fromLatin1("false") ) );
 	return el;
 }
 
@@ -936,7 +986,7 @@ QVariant KexiDB::emptyValueForType( KexiDB::Field::Type type )
 		ADD(Field::Boolean, QVariant(false, 0));
 		ADD(Field::Float, 0.0);
 		ADD(Field::Double, 0.0);
-//! @ok? we have no better defaults
+//! @todo ok? we have no better defaults
 		ADD(Field::Text, QString(" "));
 		ADD(Field::LongText, QString(" "));
 		ADD(Field::BLOB, QByteArray());
@@ -1063,6 +1113,54 @@ QString KexiDB::escapeBLOB(const QByteArray& array, BLOBEscapingType type)
 	return str;
 }
 
+QByteArray KexiDB::pgsqlByteaToByteArray(const char* data, int length)
+{
+	QByteArray array;
+	int output=0;
+	for (int pass=0; pass<2; pass++) {//2 passes to avoid allocating buffer twice:
+		                                //  0: count #of chars; 1: copy data
+		const char* s = data;
+		const char* end = s + length;
+		if (pass==1) {
+			KexiDBDbg << "processBinaryData(): real size == " << output << endl;
+			array.resize(output);
+			output=0;
+		}
+		for (int input=0; s < end; output++) {
+	//		KexiDBDbg<<(int)s[0]<<" "<<(int)s[1]<<" "<<(int)s[2]<<" "<<(int)s[3]<<" "<<(int)s[4]<<endl;
+			if (s[0]=='\\' && (s+1)<end) {
+				//special cases as in http://www.postgresql.org/docs/8.1/interactive/datatype-binary.html
+				if (s[1]=='\'') {// \'
+					if (pass==1)
+						array[output] = '\'';
+					s+=2;
+				}
+				else if (s[1]=='\\') { // 2 backslashes 
+					if (pass==1)
+						array[output] = '\\';
+					s+=2;
+				}
+				else if ((input+3)<length) {// \\xyz where xyz are 3 octal digits
+					if (pass==1)
+						array[output] = char( (int(s[1]-'0')*8+int(s[2]-'0'))*8+int(s[3]-'0') );
+					s+=4;
+				}
+				else {
+					KexiDBDrvWarn << "processBinaryData(): no octal value after backslash" << endl;
+					s++;
+				}
+			}
+			else {
+				if (pass==1)
+					array[output] = s[0];
+				s++;
+			}
+	//		KexiDBDbg<<output<<": "<<(int)array[output]<<endl;
+		}
+	}
+	return array;
+}
+
 QString KexiDB::variantToString( const QVariant& v )
 {
 	if (v.type()==QVariant::ByteArray)
