@@ -1,5 +1,5 @@
 /* This file is part of the KDE project
-   Copyright (C) 2004-2006 Jaroslaw Staniek <js@iidea.pl>
+   Copyright (C) 2004-2007 Jaroslaw Staniek <js@iidea.pl>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -110,7 +110,7 @@ namespace KexiDB
 
 	/*! Sets \a msg to an error message retrieved from object \a obj, and \a details
 	 to details of this error (server message and result number).
-	 Does nothing if \a obj is null or no error occured.
+	 Does nothing if \a obj is null or no error occurred.
 	 \a msg and \a details strings are not overwritten.
 	 If \a msg is not empty, \a obj's error message is appended to \a details.
 	 */
@@ -188,6 +188,9 @@ namespace KexiDB
 			//! \return caption (if present) or name of the table/query
 			QString captionOrName() const;
 
+			//! \return number of fields
+			uint fieldCount() const;
+
 			//! \return all columns for the table or the query
 			const QueryColumnInfo::Vector columns(bool unique = false);
 
@@ -216,17 +219,27 @@ namespace KexiDB
 	};
 
 //! @todo perhaps use Q_ULLONG here?
-	/*! \return a number of rows that can be retrieved from \a tableSchema. 
-	 The table must be created or retrieved using a Connection object,
-	 i.e. tableSchema.connection() must not return 0.
-	 For SQL sata sources it does not fetch any records, only "COUNT()" 
+	/*! \return number of rows that can be retrieved after executing \a sql statement
+	 within a connection \a conn. The statement should be of type SELECT.
+	 For SQL data sources it does not fetch any records, only "COUNT(*)" 
 	 SQL aggregation is used at the backed. 
 	 -1 is returned if error occured. */
+	int rowCount(Connection &conn, const QString& sql);
+
+//! @todo perhaps use Q_ULLONG here?
+	/*! \return number of rows that can be retrieved from \a tableSchema. 
+	 The table must be created or retrieved using a Connection object,
+	 i.e. tableSchema.connection() must not return 0.
+	 For SQL data sources it does not fetch any records, only "COUNT(*)" 
+	 SQL aggregation is used at the backed. 
+	 -1 is returned if error occurred. */
 	KEXI_DB_EXPORT int rowCount(const TableSchema& tableSchema);
 
+//! @todo perhaps use Q_ULLONG here?
 	/*! Like above but operates on a query schema. */
 	KEXI_DB_EXPORT int rowCount(QuerySchema& querySchema);
 
+//! @todo perhaps use Q_ULLONG here?
 	/*! Like above but operates on a table or query schema variant. */
 	KEXI_DB_EXPORT int rowCount(TableOrQuerySchema& tableOrQuery);
 
@@ -251,7 +264,7 @@ namespace KexiDB
 	//! Used in splitToTableAndFieldParts().
 	enum SplitToTableAndFieldPartsOptions {
 		FailIfNoTableOrFieldName = 0, //!< default value for splitToTableAndFieldParts()
-		SetFieldNameIfNoTableName = 1 //!< @see splitToTableAndFieldParts()
+		SetFieldNameIfNoTableName = 1 //!< see splitToTableAndFieldParts()
 	};
 
 	/*! Splits \a string like "table.field" into "table" and "field" parts. 
@@ -318,7 +331,7 @@ namespace KexiDB
 		const QVariant& value);
 
 	/*! @return property value loaded from a DOM \a node, written in a QtDesigner-like
-	 notation: <number>int</number> or <bool>bool</bool>, etc. Supported types are
+	 notation: &lt;number&gt;int&lt;/number&gt; or &lt;bool&gt;bool&lt;/bool&gt;, etc. Supported types are
 	 "string", "cstring", "bool", "number". For invalid values null QVariant is returned.
 	 You can check the validity of the returned value using QVariant::type(). */
 	KEXI_DB_EXPORT QVariant loadPropertyValueFromDom( const QDomNode& node );
@@ -336,14 +349,14 @@ namespace KexiDB
 	  <height><number>15</number></height>
 	 \endcode
 	 \return the reference to element created with tag elementName. */
-	QDomElement saveNumberElementToDom(QDomDocument& doc, QDomElement& parentEl, 
+	KEXI_DB_EXPORT QDomElement saveNumberElementToDom(QDomDocument& doc, QDomElement& parentEl, 
 		const QString& elementName, int value);
 
 	/*! Saves boolean element for value \a value to \a doc document within parent element
 	 \a parentEl. Like saveNumberElementToDom() but creates "bool" tags. True/false values will be
 	 saved as "true"/"false" strings. 
 	 \return the reference to element created with tag elementName. */
-	QDomElement saveBooleanElementToDom(QDomDocument& doc, QDomElement& parentEl, 
+	KEXI_DB_EXPORT QDomElement saveBooleanElementToDom(QDomDocument& doc, QDomElement& parentEl, 
 		const QString& elementName, bool value);
 
 	/*! \return an empty value that can be set for a database field of type \a type having 
@@ -383,6 +396,12 @@ namespace KexiDB
 	 This is helper, used in Driver::escapeBLOB() and KexiDB::variantToString(). */
 	KEXI_DB_EXPORT QString escapeBLOB(const QByteArray& array, BLOBEscapingType type);
 
+	/*! \return byte array converted from \a data of length \a length.
+	 \a data is escaped in format used by PostgreSQL's bytea datatype 
+	 described at http://www.postgresql.org/docs/8.1/interactive/datatype-binary.html 
+	 This function is used by PostgreSQL KexiDB and migration drivers. */
+	KEXI_DB_EXPORT QByteArray pgsqlByteaToByteArray(const char* data, int length);
+
 	/*! \return string value serialized from a variant value \a v.
 	 This functions works like QVariant::toString() except the case when \a v is of type ByteArray.
 	 In this case KexiDB::escapeBLOB(v.toByteArray(), KexiDB::BLOBEscapeHex) is used. 
@@ -415,6 +434,36 @@ namespace KexiDB
 	/*! \return type that's maximum of two integer types \a t1 and \a t2, e.g. Integer for (Byte, Integer). 
 	 If one of the types is not of the integer group, Field::InvalidType is returned. */
 	KEXI_DB_EXPORT Field::Type maximumForIntegerTypes(Field::Type t1, Field::Type t2);
+
+	/*! \return QVariant value converted from null-terminated \a data string. 
+	 In case of BLOB type, \a data is not nul lterminated, so passing length is needed. */
+	inline QVariant cstringToVariant(const char* data, KexiDB::Field* f, int length = -1)
+	{
+		if (!data)
+			return QVariant();
+		// from mo st to least frequently used types:
+
+		if (!f || f->isTextType())
+			return QString::fromUtf8(data, length);
+		if (f->isIntegerType()) {
+			if (f->type()==KexiDB::Field::BigInteger)
+				return QVariant( QString::fromLatin1(data, length).toLongLong() );
+			return QVariant( QString::fromLatin1(data, length).toInt() );
+		}
+		if (f->isFPNumericType())
+			return QString::fromLatin1(data, length).toDouble();
+		if (f->type()==KexiDB::Field::BLOB) {
+			QByteArray ba;
+			ba.duplicate(data, length);
+			return ba;
+		}
+		// the default
+//! @todo date/time?
+		QVariant result(QString::fromUtf8(data, length));
+		if (!result.cast( KexiDB::Field::variantType(f->type()) ))
+			return QVariant();
+		return result;
+	}
 }
 
 #endif
