@@ -24,20 +24,30 @@
 #include <qpainter.h>
 #include <qimage.h>
 #include <qwmatrix.h>
+#include <qiconset.h>
+#include <qbitmap.h>
 
 #include <kdebug.h>
 #include <kcursor.h>
 #include <kapplication.h>
+#include <kpixmap.h>
+#include <kiconeffect.h>
+#include <kpixmapeffect.h>
+#include <kiconloader.h>
 
 using namespace KexiUtils;
 
-DelayedCursorHandler::DelayedCursorHandler() {
+DelayedCursorHandler::DelayedCursorHandler() 
+ : startedOrActive(false)
+{
 	connect(&timer, SIGNAL(timeout()), this, SLOT(show()));
 }
 void DelayedCursorHandler::start(bool noDelay) {
+	startedOrActive = true;
 	timer.start(noDelay ? 0 : 1000, true);
 }
 void DelayedCursorHandler::stop() {
+	startedOrActive = false;
 	timer.stop();
 	QApplication::restoreOverrideCursor();
 }
@@ -66,6 +76,17 @@ WaitCursor::~WaitCursor()
 	removeWaitCursor();
 }
 
+WaitCursorRemover::WaitCursorRemover()
+{
+	m_reactivateCursor = _delayedCursorHandler.startedOrActive;
+	_delayedCursorHandler.stop();
+}
+
+WaitCursorRemover::~WaitCursorRemover()
+{
+	_delayedCursorHandler.start(true);
+}
+
 //--------------------------------------------------------------------------------
 
 QString KexiUtils::fileDialogFilterString(const KMimeType::Ptr& mime, bool kdeFormat)
@@ -147,6 +168,25 @@ QColor KexiUtils::bleachedColor(const QColor& c, int factor)
 	return c2;
 }
 
+QIconSet KexiUtils::colorizeIconToTextColor(const QPixmap& icon, const QPalette& palette)
+{
+	QPixmap pm(
+		KIconEffect().apply( icon, KIconEffect::Colorize, 1.0f, palette.active().buttonText(), false ) );
+
+	KPixmap kpm(pm);
+	return QIconSet(
+		KPixmapEffect::fade( kpm, 0.33, palette.active().button() ) );
+}
+
+QPixmap KexiUtils::emptyIcon(KIcon::Group iconGroup)
+{
+	QPixmap noIcon( IconSize( iconGroup ), IconSize( iconGroup ) );
+	QBitmap bmpNoIcon(noIcon.size());
+	bmpNoIcon.fill(Qt::color0);
+	noIcon.setMask(bmpNoIcon);
+	return noIcon;
+}
+
 void KexiUtils::serializeMap(const QMap<QString,QString>& map, const QByteArray& array)
 {
 	QDataStream ds(array, IO_WriteOnly);
@@ -287,7 +327,7 @@ void KexiUtils::drawPixmap( QPainter& p, int lineWidth, const QRect& rect,
 //		target->drawPixmap(pos, pixmap);
 //		if (!fast)
 //			p2.begin(&pixmapBuffer, p.device());
-		p.drawPixmap(lineWidth, lineWidth, pixmap);
+		p.drawPixmap(lineWidth+pos.x(), lineWidth+pos.y(), pixmap);
 	}
 	if (scaledContents && !fast && p.isActive()) {
 		p2.end();
