@@ -165,6 +165,9 @@ namespace KexiUtils
 	 with accessibility settings. */
 	KEXIUTILS_EXPORT QIconSet colorizeIconToTextColor(const QPixmap& icon, const QPalette& palette);
 
+	/*! \return empty (fully transparent) pixmap that can be used as a place for icon of size \a iconGroup */
+	KEXIUTILS_EXPORT QPixmap emptyIcon(KIcon::Group iconGroup);
+
 	/*! Serializes \a map to \a array.
 	 KexiUtils::deserializeMap() can be used to deserialize this array back to map. */
 	KEXIUTILS_EXPORT void serializeMap(const QMap<QString,QString>& map, const QByteArray& array);
@@ -179,7 +182,7 @@ namespace KexiUtils
 	KEXIUTILS_EXPORT QMap<QString,QString> deserializeMap(const QString& string);
 
 	/*! \return a valid filename converted from \a string by:
-	 - replacing \\, /, :, *, ?, ", <, >, |, \n \t characters with a space
+	 - replacing \\, /, :, *, ?, ", <, >, |, \n \\t characters with a space
 	 - simplifing whitespace by removing redundant space characters using QString::simplifyWhiteSpace()
 	 Do not pass full paths here, but only filename strings. */
 	KEXIUTILS_EXPORT QString stringToFileName(const QString& string);
