@@ -1,5 +1,5 @@
 /* This file is part of the KDE project
-   Copyright (C) 2004 Jaroslaw Staniek <js@iidea.pl>
+   Copyright (C) 2004, 2006 Jaroslaw Staniek <js@iidea.pl>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -63,7 +63,7 @@ MultiValidator::MultiValidator(QObject* parent, const char * name)
 	m_ownedSubValidators.setAutoDelete(true);
 }
 
-MultiValidator::MultiValidator(Validator *validator, 
+MultiValidator::MultiValidator(QValidator *validator, 
 	QObject * parent, const char * name)
  : Validator(parent, name)
 {
@@ -71,7 +71,7 @@ MultiValidator::MultiValidator(Validator *validator,
 }
 
 
-void MultiValidator::addSubvalidator( Validator* validator, bool owned )
+void MultiValidator::addSubvalidator( QValidator* validator, bool owned )
 {
 	if (!validator)
 		return;
@@ -82,11 +82,8 @@ void MultiValidator::addSubvalidator( Validator* validator, bool owned )
 
 QValidator::State MultiValidator::validate( QString & input, int & pos ) const
 {
-	if (m_subValidators.isEmpty())
-		return Invalid;
 	State s;
-	QValueList<Validator*>::ConstIterator it, end( m_subValidators.constEnd() );
-	for ( it = m_subValidators.constBegin(); it != end; ++it) {
+	foreach( QValueList<QValidator*>::ConstIterator, it,  m_subValidators ) {
 		s = (*it)->validate(input, pos);
 		if (s==Intermediate || s==Invalid)
 			return s;
@@ -96,26 +93,24 @@ QValidator::State MultiValidator::validate( QString & input, int & pos ) const
 
 void MultiValidator::fixup ( QString & input ) const
 {
-	QValueList<Validator*>::ConstIterator it, end( m_subValidators.constEnd() );
-	for ( it = m_subValidators.constBegin(); it != end; ++it) {
+	foreach( QValueList<QValidator*>::ConstIterator, it,  m_subValidators )
 		(*it)->fixup(input);
-	}
 }
 
 Validator::Result MultiValidator::internalCheck(
 	const QString &valueName, const QVariant& v, 
 	QString &message, QString &details)
 {
-	if (m_subValidators.isEmpty())
-		return Error;
 	Result r;
 	bool warning = false;
-	QValueList<Validator*>::ConstIterator it, end( m_subValidators.end() );
-	for ( it=m_subValidators.begin(); it!=end; ++it) {
-		r = (*it)->internalCheck(valueName, v, message, details);
+	foreach( QValueList<QValidator*>::ConstIterator, it,  m_subValidators ) {
+		if (dynamic_cast<Validator*>(*it))
+			r = dynamic_cast<Validator*>(*it)->internalCheck(valueName, v, message, details);
+		else
+			r = Ok; //ignore
 		if (r==Error)
 			return Error;
-		if (r==Warning)
+		else if (r==Warning)
 			warning = true;
 	}
 	return warning ? Warning : Ok;
