@@ -1,5 +1,5 @@
 /* This file is part of the KDE project
-   Copyright (C) 2003-2006 Jaroslaw Staniek <js@iidea.pl>
+   Copyright (C) 2003-2007 Jaroslaw Staniek <js@iidea.pl>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -224,9 +224,15 @@ bool KexiStartupHandler::getAutoopenObjects(KCmdLineArgs *args, const QCString &
 			name_required = false;
 		}
 		else {//open, design, text...
-			//option with " " (default type == "table")
+			QString defaultType;
+			if (action_name=="execute")
+				defaultType = "macro";
+			else
+				defaultType = "table";
+
+			//option with " " (set default type)
 			if (stripQuotes(item, obj_name)) {
-				type_name = "table";
+				type_name = defaultType;
 			}
 			else if ((idx = item.find(':'))!=-1) {
 				//option with type name specified:
@@ -237,9 +243,9 @@ bool KexiStartupHandler::getAutoopenObjects(KCmdLineArgs *args, const QCString &
 					obj_name = obj_name.mid(1, obj_name.length()-2);
 			}
 			else {
-				//just obj. name: type name is "table" by default
+				//just obj. name: set default type name
 				obj_name = item;
-				type_name = "table";
+				type_name = defaultType;
 			}
 		}
 		if (type_name.isEmpty())
@@ -298,14 +304,12 @@ tristate KexiStartupHandler::init(int /*argc*/, char ** /*argv*/)
 
 //	if (cdata.driverName.isEmpty())
 //		cdata.driverName = KexiDB::Driver::defaultFileBasedDriverName();
-#ifdef KEXI_SERVER_SUPPORT
 	if (!args->getOption("host").isEmpty())
 		cdata.hostName = args->getOption("host");
 	if (!args->getOption("local-socket").isEmpty())
 		cdata.localSocketFileName = args->getOption("local-socket");
 	if (!args->getOption("user").isEmpty())
 		cdata.userName = args->getOption("user");
-#endif
 //	cdata.password = args->getOption("password");
 	bool fileDriverSelected;
 	if (cdata.driverName.isEmpty())
@@ -314,7 +318,7 @@ tristate KexiStartupHandler::init(int /*argc*/, char ** /*argv*/)
 		KexiDB::DriverManager dm;
 		KexiDB::Driver::Info dinfo = dm.driverInfo(cdata.driverName);
 		if (dinfo.name.isEmpty()) {
-			//driver name provided explicity, but not found
+			//driver name provided explicitly, but not found
 			KMessageBox::sorry(0, dm.errorMsg());
 			return false;
 		}
@@ -340,7 +344,6 @@ tristate KexiStartupHandler::init(int /*argc*/, char ** /*argv*/)
 	}
 	*/
 	
-#ifdef KEXI_SERVER_SUPPORT
 	const QString portStr = args->getOption("port");
 	if (!portStr.isEmpty()) {
 		bool ok;
@@ -353,24 +356,20 @@ tristate KexiStartupHandler::init(int /*argc*/, char ** /*argv*/)
 			return false;
 		}
 	}
-#endif
 
-#ifdef KEXI_SHOW_UNIMPLEMENTED
-	m_forcedFinalMode = args->isSet("final-mode");
+	m_forcedUserMode = args->isSet("user-mode");
 	m_forcedDesignMode = args->isSet("design-mode");
-#else
-	m_forcedFinalMode = false;
-	m_forcedDesignMode = false;
-#endif
+	m_isProjectNavigatorVisible = args->isSet("show-navigator");
 	bool createDB = args->isSet("createdb");
 	const bool alsoOpenDB = args->isSet("create-opendb");
 	if (alsoOpenDB)
 		createDB = true;
 	const bool dropDB = args->isSet("dropdb");
 	const bool openExisting = !createDB && !dropDB;
+	const bool readOnly = args->isSet("readonly");
 	const QString couldnotMsg = QString::fromLatin1("\n")
 		+i18n("Could not start Kexi application this way.");
-	
+
 	if (createDB && dropDB) {
 		KMessageBox::sorry( 0, i18n(
 			"You have used both \"createdb\" and \"dropdb\" startup options.")+couldnotMsg);
@@ -412,9 +411,9 @@ tristate KexiStartupHandler::init(int /*argc*/, char ** /*argv*/)
 		kdDebug() << "ARG" <<i<< "= " << args->arg(i) <<endl;
 	}*/
 
-	if (m_forcedFinalMode && m_forcedDesignMode) {
+	if (m_forcedUserMode && m_forcedDesignMode) {
 		KMessageBox::sorry( 0, i18n(
-		"You have used both \"final-mode\" and \"design-mode\" startup options.")+couldnotMsg);
+		"You have used both \"user-mode\" and \"design-mode\" startup options.")+couldnotMsg);
 		return false;
 	}
 
@@ -519,7 +518,7 @@ tristate KexiStartupHandler::init(int /*argc*/, char ** /*argv*/)
 						return false;
 					}
 					bool cancel = false;
-					const bool showConnectionDialog = !args->isSet("skip-dialog");
+					const bool showConnectionDialog = !args->isSet("skip-conn-dialog");
 					while (true) {
 						if (showConnectionDialog) {
 							//show connection dialog, so user can change parameters
@@ -592,6 +591,7 @@ tristate KexiStartupHandler::init(int /*argc*/, char ** /*argv*/)
 	const bool atLeastOneAOOFound = getAutoopenObjects(args, "open")
 		|| getAutoopenObjects(args, "design")
 		|| getAutoopenObjects(args, "edittext")
+		|| getAutoopenObjects(args, "execute")
 		|| getAutoopenObjects(args, "new")
 		|| getAutoopenObjects(args, "print")
 		|| getAutoopenObjects(args, "print-preview");
@@ -623,7 +623,7 @@ tristate KexiStartupHandler::init(int /*argc*/, char ** /*argv*/)
 	else if (dropDB) {
 		KexiGUIMessageHandler gui;
 		tristate res = KexiProject::dropProject(projectData(), &gui, false/*ask*/);
-		if (res)
+		if (res==true)
 			KMessageBox::information( 0, i18n("Project \"%1\" dropped successfully.")
 				.arg( QDir::convertSeparators(projectData()->databaseName()) ));
 		return res!=false;
@@ -640,7 +640,7 @@ tristate KexiStartupHandler::init(int /*argc*/, char ** /*argv*/)
 	if (!m_projectData) {
 		cdata = KexiDB::ConnectionData(); //clear
 
-		if (!KexiStartupDialog::shouldBeShown())
+		if (args->isSet("skip-startup-dialog") || !KexiStartupDialog::shouldBeShown())
 			return true;
 
 		if (!d->startupDialog) {
@@ -722,6 +722,7 @@ tristate KexiStartupHandler::init(int /*argc*/, char ** /*argv*/)
 	}
 	
 	if (m_projectData && (openExisting || (createDB && alsoOpenDB))) {
+		m_projectData->setReadOnly( readOnly );
 		m_action = OpenProject;
 	}
 	//show if wasn't show yet
@@ -739,11 +740,12 @@ tristate KexiStartupHandler::detectActionForFile(
 	detectedDriverName = QString::null;
 	QFileInfo finfo(dbFileName);
 	if (dbFileName.isEmpty() || !finfo.isReadable()) {
-		KMessageBox::sorry(parent, i18n("<p>Could not open project.</p>")
-			+i18n("<p>The file <nobr>\"%1\"</nobr> does not exist or is not readable.</p>")
-			.arg(QDir::convertSeparators(dbFileName))
-			+i18n("Check the file's permissions and whether it is already opened "
-			"and locked by another application."));
+		if (!(options & SkipMessages))
+			KMessageBox::sorry(parent, i18n("<p>Could not open project.</p>")
+				+i18n("<p>The file <nobr>\"%1\"</nobr> does not exist or is not readable.</p>")
+				.arg(QDir::convertSeparators(dbFileName))
+				+i18n("Check the file's permissions and whether it is already opened "
+				"and locked by another application."));
 		return false;
 	}
 
@@ -770,11 +772,12 @@ tristate KexiStartupHandler::detectActionForFile(
 		QFile f(dbFileName);
 		if (!f.open(IO_ReadOnly)) {
 			// BTW: similar error msg is provided in SQLiteConnection::drv_useDatabase()
-			KMessageBox::sorry(parent, i18n("<p>Could not open project.</p>")
-				+i18n("<p>The file <nobr>\"%1\"</nobr> is not readable.</p>")
-				.arg(QDir::convertSeparators(dbFileName))
-				+i18n("Check the file's permissions and whether it is already opened "
-					"and locked by another application."));
+			if (!(options & SkipMessages))
+				KMessageBox::sorry(parent, i18n("<p>Could not open project.</p>")
+					+i18n("<p>The file <nobr>\"%1\"</nobr> is not readable.</p>")
+					.arg(QDir::convertSeparators(dbFileName))
+					+i18n("Check the file's permissions and whether it is already opened "
+						"and locked by another application."));
 			return false;
 		}
 	}
@@ -792,8 +795,8 @@ tristate KexiStartupHandler::detectActionForFile(
 	//! X-KexiSupportedMimeTypes [strlist] property
 	if (ptr.data()) {
 		if (mimename=="application/x-msaccess") {
-			if (KMessageBox::Yes != KMessageBox::questionYesNo(parent, i18n(
-				"\"%1\" is an external file of type:\n\"%2\".\n"
+			if ((options & SkipMessages) || KMessageBox::Yes != KMessageBox::questionYesNo(
+				parent, i18n("\"%1\" is an external file of type:\n\"%2\".\n"
 				"Do you want to import the file as a Kexi project?")
 				.arg(QDir::convertSeparators(dbFileName)).arg(ptr.data()->comment()),
 				i18n("Open External File"), KGuiItem(i18n("Import...")), KStdGuiItem::cancel() ) )
@@ -815,12 +818,14 @@ tristate KexiStartupHandler::detectActionForFile(
 //@todo What about trying to reuse KOFFICE FILTER CHAINS here?
 	bool useDetectedDriver = suggestedDriverName.isEmpty() || suggestedDriverName.lower()==detectedDriverName.lower();
 	if (!useDetectedDriver) {
-		int res = KMessageBox::warningYesNoCancel(parent, i18n(
-			"The project file \"%1\" is recognized as compatible with \"%2\" database driver, "
-			"while you have asked for \"%3\" database driver to be used.\n"
-			"Do you want to use \"%4\" database driver?")
-			.arg(QDir::convertSeparators(dbFileName))
-			.arg(tmpDriverName).arg(suggestedDriverName).arg(tmpDriverName));
+		int res = KMessageBox::Yes;
+		if (!(options & SkipMessages))
+			res = KMessageBox::warningYesNoCancel(parent, i18n(
+			 "The project file \"%1\" is recognized as compatible with \"%2\" database driver, "
+			 "while you have asked for \"%3\" database driver to be used.\n"
+			 "Do you want to use \"%4\" database driver?")
+			 .arg(QDir::convertSeparators(dbFileName))
+			 .arg(tmpDriverName).arg(suggestedDriverName).arg(tmpDriverName));
 		if (KMessageBox::Yes == res)
 			useDetectedDriver = true;
 		else if (KMessageBox::Cancel == res)
@@ -835,7 +840,7 @@ tristate KexiStartupHandler::detectActionForFile(
 //	kdDebug() << "KexiStartupHandler::detectActionForFile(): driver name: " << detectedDriverName << endl;
 //hardcoded for convenience:
 	const QString newFileFormat = "SQLite3";
-	if (!(options & DontConvert) 
+	if (!(options & DontConvert || options & SkipMessages) 
 		&& detectedDriverName.lower()=="sqlite2" && detectedDriverName.lower()!=suggestedDriverName.lower()
 		&& KMessageBox::Yes == KMessageBox::questionYesNo(parent, i18n(
 			"Previous version of database file format (\"%1\") is detected in the \"%2\" "
@@ -854,7 +859,7 @@ tristate KexiStartupHandler::detectActionForFile(
 				.arg(QDir::convertSeparators(dbFileName)).arg(newFileFormat) );
 			//continue...
 		}
-		if (res)
+		if (res==true)
 			detectedDriverName = newFileFormat;
 	}
 //	action.driverName = detectedDriverName;
@@ -864,16 +869,17 @@ tristate KexiStartupHandler::detectActionForFile(
 			possibleProblemsInfoMsg.prepend(QString::fromLatin1("<p>")+i18n("Possible problems:"));
 			possibleProblemsInfoMsg += QString::fromLatin1("</p>");
 		}
-		KMessageBox::detailedSorry(parent, 
-			i18n( "The file \"%1\" is not recognized as being supported by Kexi.")
-				.arg(QDir::convertSeparators(dbFileName)),
-			QString::fromLatin1("<p>")
-			+i18n("Database driver for this file type not found.\nDetected MIME type: %1")
-				.arg(mimename)
-			+(ptr.data()->comment().isEmpty() 
-				? QString::fromLatin1(".") : QString::fromLatin1(" (%1).").arg(ptr.data()->comment()))
-			+QString::fromLatin1("</p>")
-			+possibleProblemsInfoMsg);
+		if (!(options & SkipMessages))
+			KMessageBox::detailedSorry(parent, 
+				i18n( "The file \"%1\" is not recognized as being supported by Kexi.")
+					.arg(QDir::convertSeparators(dbFileName)),
+				QString::fromLatin1("<p>")
+				+i18n("Database driver for this file type not found.\nDetected MIME type: %1")
+					.arg(mimename)
+				+(ptr.data()->comment().isEmpty() 
+					? QString::fromLatin1(".") : QString::fromLatin1(" (%1).").arg(ptr.data()->comment()))
+				+QString::fromLatin1("</p>")
+				+possibleProblemsInfoMsg);
 		return false;
 	}
 	return true;
