@@ -147,7 +147,6 @@ void KexiStartupFileDialog::updateFilters()
 			allfilters += mime->patterns();
 		}
 	}
-#ifdef KEXI_SERVER_SUPPORT
 	if (normalOpeningMode || m_mode & SavingServerBasedDB) {
 		mime = KMimeType::mimeType("application/x-kexiproject-shortcut");
 		if (mime && m_excludedMimeTypes.find(mime->name())==m_excludedMimeTypes.end()) {
@@ -162,7 +161,6 @@ void KexiStartupFileDialog::updateFilters()
 			allfilters += mime->patterns();
 		}
 	}
-#endif
 
 //! @todo hardcoded for MSA:
 	if (normalOpeningMode) {
@@ -335,8 +333,8 @@ void KexiStartupFileDialog::accept()
 //	QApplication::postEvent(locationEdit, &ev);
 	
 //	kdDebug() << "KexiStartupFileDialog::accept() m_lastUrl == " << m_lastUrl.path() << endl;
-//	if (m_lastUrl.path()==currentURL().path()) {//(js) to prevent more multiple kjob signals (i dont know why this is)
-	if (m_lastFileName==currentFileName()) {//(js) to prevent more multiple kjob signals (i dont know why this is)
+//	if (m_lastUrl.path()==currentURL().path()) {//(js) to prevent more multiple kjob signals (I do not know why this is)
+	if (m_lastFileName==currentFileName()) {//(js) to prevent more multiple kjob signals (I do not know why this is)
 //		m_lastUrl=KURL();
 		m_lastFileName=QString::null;
 		kdDebug() << "m_lastFileName==currentFileName()" << endl;
