@@ -1,6 +1,6 @@
 /* This file is part of the KDE project
    Copyright (C) 2004 Adam Pigg <adam@piggz.co.uk>
-   Copyright (C) 2004-2005 Jaroslaw Staniek <js@iidea.pl>
+   Copyright (C) 2004-2006 Jaroslaw Staniek <js@iidea.pl>
    Copyright (C) 2005 Martin Ellis <martin.ellis@kdemail.net>
 
    This program is free software; you can redistribute it and/or
@@ -38,8 +38,8 @@ KexiMigrate::KexiMigrate(QObject *parent, const char *name,
   : QObject( parent, name )
   , m_migrateData(0)
   , m_destPrj(0)
-//  , m_copyOfKexi__objects(0)
 {
+	m_kexiDBCompatibleTableSchemasToRemoveFromMemoryAfterImport.setAutoDelete(true);
 }
 
 //! Used for computing progress: 
@@ -151,9 +151,6 @@ bool KexiMigrate::performImport(Kexi::ObjectStatus* result)
 		return false;
 	}
 
-	//tmp to force error!!!
-	//tables.prepend("$$$$$");
-
 	// Check if there are any tables
 	if (tables.isEmpty()) {
 		kdDebug() << "There were no tables to import" << endl;
@@ -165,30 +162,41 @@ bool KexiMigrate::performImport(Kexi::ObjectStatus* result)
 	}
 
 	// Step 3 - Read table schemas
+	tables.sort();
 	m_tableSchemas.clear();
 	if (!destDriver) {
 		result->setStatus(&drvManager);
 		return false;
 	}
-	foreach(QStringList::ConstIterator, it, tables) {
+	const bool kexi__objects_exists = tables.find("kexi__objects")!=tables.end();
+	QStringList kexiDBTables;
+	if (kexi__objects_exists) {
+		tristate res = drv_queryStringListFromSQL(
+			QString::fromLatin1("SELECT o_name FROM kexi__objects WHERE o_type=%1")
+		.arg((int)KexiDB::TableObjectType), 0, kexiDBTables, -1);
+		if (res == true) {
+			// prepend KexiDB-compatible tables to 'tables' list, so we'll copy KexiDB-compatible tables first,
+			// to make sure existing IDs will not be in conflict with IDs newly generated for non-KexiDB tables
+			kexiDBTables.sort();
+			foreach(QStringList::ConstIterator, it, kexiDBTables)
+				tables.remove( *it );
+//kdDebug() << "KexiDB-compat tables: " << kexiDBTables << endl;
+//kdDebug() << "non-KexiDB tables: " << tables << endl;
+		}
+	}
+
+	uint i=0;
+	// -- read table schemas and create them in memory (only for non-KexiDB-compat tables)
+	foreach (QStringList::ConstIterator, it, tables) {
 		if (destDriver->isSystemObjectName( *it ) //"kexi__objects", etc.
 			|| (*it).lower().startsWith("kexi__")) //tables at KexiProject level, e.g. "kexi__blobs"
 			continue;
-
+		// this is a non-KexiDB table: generate schema from native data source
 		const QString tableName( KexiUtils::string2Identifier(*it) );
-		KexiDB::TableSchema *tableSchema;
-//		if (tableName.lower().startsWith("kexi__"))
-//			tableSchema = new KexiDB::InternalTableSchema(tableName);
-//		else
-		tableSchema = new KexiDB::TableSchema(tableName);
-
+		KexiDB::TableSchema *tableSchema = new KexiDB::TableSchema(tableName);
 		tableSchema->setCaption( *it ); //caption is equal to the original name
 
-		if (drv_readTableSchema(*it, *tableSchema)) {
-			//yeah, got a table
-			//Add it to list of tables which we will create if all goes well
-			m_tableSchemas.append(tableSchema);
-		} else {
+		if (!drv_readTableSchema(*it, *tableSchema)) {
 			delete tableSchema;
 			if (result)
 				result->setStatus(
@@ -196,128 +204,219 @@ bool KexiMigrate::performImport(Kexi::ObjectStatus* result)
 					.arg(m_migrateData->source->serverInfoString()).arg(tableName), "");
 			return false;
 		}
+		//yeah, got a table
+		//Add it to list of tables which we will create if all goes well
+		m_tableSchemas.append(tableSchema);
 	}
 
-	// Step 4 - Create new database as we have all required info
+	// Step 4 - Create a new database as we have all required info
+	// - create copies of KexiDB-compat tables
+	// - create copies of non-KexiDB tables
 	delete m_destPrj;
-	m_destPrj = createProject(result);
-	if (!m_destPrj || m_destPrj->error()) {
-		if (result)
-			result->setStatus(m_destPrj,
-				i18n("Could not import project from data source \"%1\".")
-				.arg(m_migrateData->source->serverInfoString()));
-		return false;
+	m_destPrj = new KexiProject(m_migrateData->destination, 
+		result ? (KexiDB::MessageHandler*)*result : 0);
+	bool ok = true == m_destPrj->create(true /*forceOverwrite*/);
+
+	KexiDB::Connection *destConn = 0;
+
+	if (ok)
+		ok = (destConn = m_destPrj->dbConnection());
+
+	KexiDB::Transaction trans;
+	if (ok) {
+		trans = destConn->beginTransaction();
+		if (trans.isNull()) {
+			ok = false;
+			if (result)
+				result->setStatus(destConn,
+					i18n("Could not create database \"%1\".")
+					.arg(m_migrateData->destination->databaseName()));
+			//later destConn->dropDatabase(m_migrateData->destination->databaseName());
+			//don't delete prj, otherwise eror message will be deleted		delete prj;
+			//later return m_destPrj;
+		}
+	}
+	
+	if (ok) {
+		if (drv_progressSupported())
+			progressInitialise();
+
+		// Step 5 - Create the copies of KexiDB-compat tables in memory (to maintain the same IDs)
+		m_kexiDBCompatibleTableSchemasToRemoveFromMemoryAfterImport.clear();
+		foreach (QStringList::ConstIterator, it, kexiDBTables) {
+			//load the schema from kexi__objects and kexi__fields
+			TableSchema *t = new TableSchema();
+			RowData data;
+			bool firstRecord = true;
+			if (true == drv_fetchRecordFromSQL(
+					QString("SELECT o_id, o_type, o_name, o_caption, o_desc FROM kexi__objects "
+					"WHERE o_name='%1' AND o_type=%1").arg(*it).arg((int)KexiDB::TableObjectType), 
+					data, firstRecord)
+				&& destConn->setupObjectSchemaData( data, *t ))
+			{
+//! @todo to reuse Connection::setupTableSchema()'s statement somehow...
+				//load schema for every field and add it
+				firstRecord = true;
+				QString sql(
+					QString::fromLatin1("SELECT t_id, f_type, f_name, f_length, f_precision, f_constraints, "
+						"f_options, f_default, f_order, f_caption, f_help"
+						" FROM kexi__fields WHERE t_id=%1 ORDER BY f_order").arg(t->id()) );
+				while (ok) {
+					tristate res = drv_fetchRecordFromSQL(sql, data, firstRecord);
+					if (res != true) {
+						if (false == res)
+							ok = false;
+						break;
+					}
+					KexiDB::Field* f = destConn->setupField( data );
+					if (f)
+						t->addField(f);
+					else
+						ok = false;
+				}
+				if (ok)
+					ok = destConn->drv_createTable(*t);
+				if (ok)
+					m_kexiDBCompatibleTableSchemasToRemoveFromMemoryAfterImport.append(t);
+			}
+			if (!ok)
+				delete t;
+		}
 	}
 
-	// Step 5 - Copy data if asked to
-	bool ok = true;
-	KexiDB::Transaction trans;
-	if (!m_migrateData->keepData)
-		m_tableSchemas.clear();
+	// Step 6 - Copy kexi__objects NOW because we'll soon create new objects with new IDs (3.)...
+	if (ok) {
+		if (kexi__objects_exists)
+			ok = drv_copyTable("kexi__objects", destConn, destConn->tableSchema("kexi__objects"));
+	}
 
-	KexiDB::Connection *destConn = m_destPrj->dbConnection();
-	ok = destConn;
+	// Step 7 - Create the non-KexiDB-compatible tables: new IDs will be assigned to them
+	if (ok) {
+		KexiDB::TableSchema *ts;
+		for (QPtrListIterator<TableSchema> it (m_tableSchemas); (ts = it.current()); ++it) {
+			ok = destConn->createTable( ts );
+			if (!ok) {
+				kdDebug() << "Failed to create a table " << ts->name() << endl;
+				destConn->debugError();
+				if (result)
+					result->setStatus(destConn,
+						i18n("Could not create database \"%1\".")
+						.arg(m_migrateData->destination->databaseName()));
+				m_tableSchemas.remove(ts);
+				break;
+			}
+			updateProgress((Q_ULLONG)NUM_OF_ROWS_PER_CREATE_TABLE);
+		}
+	}
+
+	if (ok)
+		ok = destConn->commitTransaction(trans);
+
+	if (ok) {
+		//add compatible tables to the list, so data will be copied, if needed
+		if (m_migrateData->keepData) {
+			for(QPtrListIterator<TableSchema> it (m_kexiDBCompatibleTableSchemasToRemoveFromMemoryAfterImport);
+				it.current(); ++it)
+			{
+				m_tableSchemas.append(it.current());
+			}
+		}
+		else
+			m_tableSchemas.clear();
+	}
+
+	if (ok) {
+		if (m_destPrj->error()) {
+			ok = false;
+			if (result)
+				result->setStatus(m_destPrj,
+					i18n("Could not import project from data source \"%1\".")
+					.arg(m_migrateData->source->serverInfoString()));
+		}
+	}
+
+	// Step 8 - Copy data if asked to
 	if (ok) {
 		trans = destConn->beginTransaction();
 		ok = !trans.isNull();
 	}
 	if (ok) {
-		// Copy data for "kexi__objectdata" as well, if available in the source db
-		if (tables.find("kexi__objectdata")!=tables.end())
-			m_tableSchemas.append(destConn->tableSchema("kexi__objectdata")); 
-	}
+		if (m_migrateData->keepData) {
+//! @todo check detailed "copy forms/blobs/tables" flags here when we add them
+			// Copy data for "kexi__objectdata" as well, if available in the source db
+			if (tables.find("kexi__objectdata")!=tables.end())
+				m_tableSchemas.append(destConn->tableSchema("kexi__objectdata")); 
+			// Copy data for "kexi__blobs" as well, if available in the source db
+			if (tables.find("kexi__blobs")!=tables.end())
+				m_tableSchemas.append(destConn->tableSchema("kexi__blobs")); 
+			// Copy data for "kexi__fields" as well, if available in the source db
+			if (tables.find("kexi__fields")!=tables.end())
+				m_tableSchemas.append(destConn->tableSchema("kexi__fields")); 
+		}
 
-	for(QPtrListIterator<TableSchema> ts(m_tableSchemas); ok && ts.current() != 0 ; ++ts)
-	{
-		const QString tname( ts.current()->name().lower() );
-		if (destConn->driver()->isSystemObjectName( tname )
-//! @todo what if these two tables are not compatible with tables created in detination db
-//! because newer db format was used?
-			&& tname!="kexi__objectdata" //copy this too
-		)
+		for(QPtrListIterator<TableSchema> ts(m_tableSchemas); ok && ts.current() != 0 ; ++ts)
 		{
-			kdDebug() << "Do not copy data for system table: " << tname << endl;
+			const QString tname( ts.current()->name().lower() );
+			if (destConn->driver()->isSystemObjectName( tname )
+//! @todo what if these two tables are not compatible with tables created in destination db
+//!       because newer db format was used?
+				&& tname!="kexi__objectdata" //copy this too
+				&& tname!="kexi__blobs" //copy this too
+				&& tname!="kexi__fields" //copy this too
+			)
+			{
+				kdDebug() << "Do not copy data for system table: " << tname << endl;
 //! @todo copy kexi__db contents!
-			continue;
-		}
-		kdDebug() << "Copying data for table: " << tname << endl;
-		ok = drv_copyTable(
-			ts.current()->caption().isEmpty() ? tname : ts.current()->caption(), //caption is equal to the original name
-			destConn, 
-			ts.current()
-		);
-		if (!ok) {
-			kdDebug() << "Failed to copy table " << tname << endl;
-			if (result)
-				result->setStatus(destConn,
-					i18n("Could not copy table \"%1\" to destination database.").arg(tname));
-			break;
-		}
-	}//for
-
-	// 5.1. Copy remaining "kexi__objects" contents (queries, forms, etc.) 
-	//      if "kexi__objects" table is available in the source db
-	if (ok && tables.find("kexi__objects")!=tables.end()) {
-		// At 'source' side, we can only can use drv_copyTable, so let's create 
-		// a temporary copy of "kexi__objects" and copy everything there
-		KexiDB::TableSchema *kexi__objectsCopy = 
-			new KexiDB::TableSchema( *destConn->tableSchema("kexi__objects") );
-		kexi__objectsCopy->setName("kexi__objects__copy");
-		ok = destConn->createTable( kexi__objectsCopy );
-		if (!ok) {
-			kdDebug() << "Failed to create a table " << kexi__objectsCopy->name() << endl;
-			delete kexi__objectsCopy;
-			kexi__objectsCopy = 0;
-			destConn->debugError();
-			if (result)
-				result->setStatus(destConn,
-					i18n("Could not create database \"%1\".")
-					.arg(m_migrateData->destination->databaseName()));
-		}
-		if (ok) {
-			ok = drv_copyTable("kexi__objects", destConn, kexi__objectsCopy);
-		}
-		//! Copy every row not being of a type 'table'
-//! @todo this is not portable to non-SQL target engines!
-		if (ok) {
-			ok = destConn->executeSQL(
-				QString::fromLatin1("INSERT INTO kexi__objects SELECT * FROM kexi__objects__copy "
-					"WHERE o_type<>%1").arg((int)KexiDB::TableObjectType));
-		}
-		if (kexi__objectsCopy && !destConn->dropTable( kexi__objectsCopy )) {
-			ok = false;
-		}
+				continue;
+			}
+			kdDebug() << "Copying data for table: " << tname << endl;
+			QString originalTableName;
+			if (kexiDBTables.find(tname)==kexiDBTables.end())
+				//caption is equal to the original name
+				originalTableName = ts.current()->caption().isEmpty() ? tname : ts.current()->caption();
+			else
+				originalTableName = tname;
+			ok = drv_copyTable(originalTableName, destConn, ts.current());
+			if (!ok) {
+				kdDebug() << "Failed to copy table " << tname << endl;
+				if (result)
+					result->setStatus(destConn,
+						i18n("Could not copy table \"%1\" to destination database.").arg(tname));
+				break;
+			}
+		}//for
 	}
 
 	// Done.
-	if (ok) {
+	if (ok)
 		ok = destConn->commitTransaction(trans);
-	}
 
 	if (ok)
-		ok = drv_disconnect(); // && m_migrateData->dest->disconnect();
+		ok = drv_disconnect();
 
-	if (!ok) {
-		if (result && result->error())
-			result->setStatus(destConn,
-				i18n("Could not import data from data source \"%1\".")
-					.arg(m_migrateData->source->serverInfoString()));
-		if (destConn) {
-			destConn->debugError();
-			destConn->rollbackTransaction(trans);
-		}
-		drv_disconnect();
-		if (destConn) {
-			destConn->disconnect();
-			destConn->dropDatabase(m_migrateData->destination->databaseName());
-		}
-		//later		delete prj;
-		return false;
+	m_kexiDBCompatibleTableSchemasToRemoveFromMemoryAfterImport.clear();
+
+	if (ok) {
+		if (destConn)
+			ok = destConn->disconnect();
+		return ok;
 	}
-	if (destConn)
-		ok = destConn->disconnect();
-	//later	delete prj;
-	return ok;
+
+	// Finally: error handling
+	if (result && result->error())
+		result->setStatus(destConn,
+			i18n("Could not import data from data source \"%1\".")
+				.arg(m_migrateData->source->serverInfoString()));
+	if (destConn) {
+		destConn->debugError();
+		destConn->rollbackTransaction(trans);
+	}
+	drv_disconnect();
+	if (destConn) {
+		destConn->disconnect();
+		destConn->dropDatabase(m_migrateData->destination->databaseName());
+	}
+	return false;
 }
 //=============================================================================
 
@@ -331,61 +430,6 @@ bool KexiMigrate::performExport(Kexi::ObjectStatus* result)
 	return false;
 }
 
-//=============================================================================
-// Create the final database project
-KexiProject *KexiMigrate::createProject(Kexi::ObjectStatus* result)
-{
-	kdDebug() << "Creating database [" << m_migrateData->destination->databaseName() 
-		<< "]" << endl;
-
-	KexiProject *prj = new KexiProject(m_migrateData->destination,
-		(KexiDB::MessageHandler*)*result);
-	tristate r = prj->create(true /*forceOverwrite*/);
-	if (r!=true) {
-		//don't delete prj, otherwise eror message will be deleted		delete prj;
-		return prj;
-	}
-
-	KexiDB::TransactionGuard tg(*prj->dbConnection());
-	if (tg.transaction().isNull()) {
-		if (result)
-			result->setStatus(prj->dbConnection(),
-				i18n("Could not create database \"%1\".")
-				.arg(m_migrateData->destination->databaseName()));
-		prj->dbConnection()->dropDatabase(m_migrateData->destination->databaseName());
-		//don't delete prj, otherwise eror message will be deleted		delete prj;
-		return prj;
-	}
-
-	if(drv_progressSupported()) {
-		progressInitialise();
-	}
-
-	//Right, were connected..create the tables
-	KexiDB::TableSchema *ts;
-	for(QPtrListIterator<TableSchema> it (m_tableSchemas); (ts = it.current()) != 0;++it) {
-		if(!prj->dbConnection()->createTable( ts )) {
-			kdDebug() << "Failed to create a table " << ts->name() << endl;
-			prj->dbConnection()->debugError();
-			if (result)
-				result->setStatus(prj->dbConnection(),
-					i18n("Could not create database \"%1\".")
-					.arg(m_migrateData->destination->databaseName()));
-			m_tableSchemas.remove(ts);
-			prj->dbConnection()->dropDatabase(m_migrateData->destination->databaseName());
-			//don't delete prj, otherwise eror message will be deleted			delete prj;
-			return prj;
-		}
-		updateProgress((Q_ULLONG)NUM_OF_ROWS_PER_CREATE_TABLE);
-	}
-	if (!tg.commit()) {
-		prj->dbConnection()->dropDatabase(m_migrateData->destination->databaseName());
-		//don't delete prj, otherwise eror message will be deleted		delete prj;
-		return prj;
-	}
-	return prj;
-}
-
 //=============================================================================
 // Functions for getting table data
 bool KexiMigrate::tableNames(QStringList & tn)
@@ -539,4 +583,34 @@ bool KexiMigrate::isValid()
 	return true;
 }
 
+bool KexiMigrate::drv_queryMaxNumber(const QString& tableName, 
+	const QString& columnName, int& result)
+{
+	QString string;
+	tristate r = drv_querySingleStringFromSQL(
+		QString::fromLatin1("SELECT MAX(%1) FROM %2").arg(drv_escapeIdentifier(columnName))
+		.arg(drv_escapeIdentifier(tableName)), 0, string);
+	if (r == false)
+		return false;
+	if (~r) {
+		result = 0;
+		return true;
+	}
+	bool ok;
+	int tmpResult = string.toInt(&ok);
+	if (ok)
+		result = tmpResult;
+	return ok;
+}
+
+tristate KexiMigrate::drv_querySingleStringFromSQL(
+	const QString& sqlStatement, uint columnNumber, QString& string)
+{
+	QStringList stringList;
+	const tristate res = drv_queryStringListFromSQL(sqlStatement, columnNumber, stringList, 1);
+	if (true == res)
+		string = stringList.first();
+	return res;
+}
+
 #include "keximigrate.moc"
