@@ -196,7 +196,7 @@ KexiDBFactory::KexiDBFactory(QObject *parent, const char *name, const QStringLis
 
 #ifndef KEXI_NO_AUTOFIELD_WIDGET
 	wi = new KexiDataAwareWidgetInfo(this);
-	wi->setPixmap("edit");
+	wi->setPixmap("autofield");
 	wi->setClassName("KexiDBAutoField");
 	wi->addAlternateClassName("KexiDBFieldEdit", true/*override*/); //older
 	wi->setName(i18n("Auto Field"));
@@ -290,8 +290,10 @@ KexiDBFactory::KexiDBFactory(QObject *parent, const char *name, const QStringLis
 	m_propDesc["dataSource"] = i18n("Data Source");
 	m_propDesc["formName"] = i18n("Form Name");
 	m_propDesc["onClickAction"] = i18n("On Click");
+	m_propDesc["onClickActionOption"] = i18n("On Click Option");
 	m_propDesc["autoTabStops"] = i18n("Auto Tab Order");
 	m_propDesc["shadowEnabled"] = i18n("Shadow Enabled");
+	m_propDesc["on"] = i18n("On: button", "On");
 
 	m_propDesc["widgetType"] = i18n("Editor Type");
 	//for autofield's type: inherit i18n from KexiDB
@@ -324,7 +326,7 @@ KexiDBFactory::KexiDBFactory(QObject *parent, const char *name, const QStringLis
 	m_propDesc["scaledContents"] = i18n("Scaled Contents");
 	m_propDesc["keepAspectRatio"] = i18n("Keep Aspect Ratio (short)", "Keep Ratio");
 
-	//hide classes that are repalced by db-aware versions
+	//hide classes that are replaced by db-aware versions
 	hideClass("KexiPictureLabel");
 	hideClass("KComboBox");
 
@@ -340,7 +342,7 @@ KexiDBFactory::KexiDBFactory(QObject *parent, const char *name, const QStringLis
 	m_propValDesc["TristateOff"] = i18n("Tristate checkbox, no", "No");
 	
 	//for combobox
-	m_propDesc["editable"] = futureI18n2("Editable combobox", "Editable");
+	m_propDesc["editable"] = i18n("Editable combobox", "Editable");
 }
 
 KexiDBFactory::~KexiDBFactory()
@@ -445,7 +447,7 @@ void
 KexiDBFactory::createCustomActions(KActionCollection* col)
 {
 	//this will create shared instance action for design mode (special collection is provided)
-	m_assignAction = new KAction( i18n("Assign Action..."), SmallIconSet("form_action"),
+	m_assignAction = new KAction( i18n("&Assign Action..."), SmallIconSet("form_action"),
 		0, 0, 0, col, "widget_assign_action");
 }
 
@@ -589,6 +591,7 @@ KexiDBFactory::isPropertyVisibleInternal(const QCString& classname, QWidget *w,
 		ok = property!="isDragEnabled"
 #ifdef KEXI_NO_UNFINISHED
 			&& property!="onClickAction" /*! @todo reenable */
+			&& property!="onClickActionOption" /*! @todo reenable */
 			&& property!="iconSet" /*! @todo reenable */
 			&& property!="stdItem" /*! @todo reenable stdItem */
 #endif
