@@ -83,6 +83,20 @@ public:
 		slotTableAdded_enabled = true;
 	}
 
+	bool changeSingleCellValue(KexiTableItem &item, int columnNumber, 
+		const QVariant& value, KexiDB::ResultInfo* result)
+	{
+		data->clearRowEditBuffer();
+		if (!data->updateRowEditBuffer(&item, columnNumber, value)
+			|| !data->saveRowChanges(item, true))
+		{
+			if (result)
+				*result = *data->result();
+			return false;
+		}
+		return true;
+	}
+
 	KexiTableViewData *data;
 	KexiDataTable *dataTable;
 	QGuardedPtr<KexiDB::Connection> conn;
@@ -161,6 +175,8 @@ KexiQueryDesignerGuiEditor::KexiQueryDesignerGuiEditor(
 			this, SLOT(slotDragOverTableRow(KexiTableItem*,int,QDragMoveEvent*)));
 		connect(d->dataTable->tableView(), SIGNAL(droppedAtRow(KexiTableItem*,int,QDropEvent*,KexiTableItem*&)),
 			this, SLOT(slotDroppedAtRow(KexiTableItem*,int,QDropEvent*,KexiTableItem*&)));
+		connect(d->dataTable->tableView(), SIGNAL(newItemAppendedForAfterDeletingInSpreadSheetMode()),
+			this, SLOT(slotNewItemAppendedForAfterDeletingInSpreadSheetMode()));
 	}
 	connect(d->data, SIGNAL(aboutToChangeCell(KexiTableItem*,int,QVariant&,KexiDB::ResultInfo*)),
 		this, SLOT(slotBeforeCellChanged(KexiTableItem*,int,QVariant&,KexiDB::ResultInfo*)));
@@ -209,7 +225,6 @@ KexiQueryDesignerGuiEditor::initTableColumns()
 	col3->field()->setDefaultValue( QVariant(false, 0) );
 	col3->field()->setNotNull( true );
 	d->data->addColumn(col3);
-	d->dataTable->tableView()->adjustColumnWidthToContents( COLUMN_ID_VISIBLE );
 
 #ifndef KEXI_NO_QUERY_TOTALS
 	KexiTableViewColumn *col4 = new KexiTableViewColumn("totals", KexiDB::Field::Enum, i18n("Totals"),
@@ -386,12 +401,13 @@ KexiQueryDesignerGuiEditor::buildSchema(QString *errMsg)
 			KexiDB::QueryColumnInfo* currentColumn = 0;
 			if (!tableName.isEmpty())
 				fieldAndTableName.prepend(tableName+".");
-			bool fieldVisible = (*set)["visible"].value().toBool();
+			const bool fieldVisible = (*set)["visible"].value().toBool();
 			QString criteriaStr = (*set)["criteria"].value().toString();
 			QCString alias = (*set)["alias"].value().toCString();
 			if (!criteriaStr.isEmpty()) {
 				int token;
-				KexiDB::BaseExpr *criteriaExpr = parseExpressionString(criteriaStr, token, true/*allowRelationalOperator*/);
+				KexiDB::BaseExpr *criteriaExpr = parseExpressionString(criteriaStr, token, 
+					true/*allowRelationalOperator*/);
 				if (!criteriaExpr) {//for sanity
 					if (errMsg)
 						*errMsg = i18n("Invalid criteria \"%1\"").arg(criteriaStr);
@@ -411,7 +427,8 @@ KexiQueryDesignerGuiEditor::buildSchema(QString *errMsg)
 				if ((*set)["isExpression"].value().toBool()==true) {
 					//add expression column
 					int dummyToken;
-					KexiDB::BaseExpr *columnExpr = parseExpressionString(fieldName, dummyToken, false/*!allowRelationalOperator*/);
+					KexiDB::BaseExpr *columnExpr = parseExpressionString(fieldName, dummyToken, 
+						false/*!allowRelationalOperator*/);
 					if (!columnExpr) {
 						if (errMsg)
 							*errMsg = i18n("Invalid expression \"%1\"").arg(fieldName);
@@ -441,7 +458,8 @@ KexiQueryDesignerGuiEditor::buildSchema(QString *errMsg)
 						fieldsFound = true;
 				} else {
 					if (!t) {
-						kexipluginswarn << "query designer: NO TABLE '" << (*set)["table"].value().toString() << "'" << endl;
+						kexipluginswarn << "query designer: NO TABLE '" 
+							<< (*set)["table"].value().toString() << "'" << endl;
 						continue;
 					}
 					currentField = t->field( fieldName );
@@ -449,8 +467,15 @@ KexiQueryDesignerGuiEditor::buildSchema(QString *errMsg)
 						kexipluginswarn << "query designer: NO FIELD '" << fieldName << "'" << endl;
 						continue;
 					}
+					if (!fieldVisible && criteriaStr.isEmpty() && (*set)["isExpression"]
+						&& (*set)["sorting"].value().toString()!="nosorting")
+					{
+						kexipluginsdbg << "invisible field with sorting: do not add it to the fields list" << endl;
+						continue;
+					}
 					temp->query()->addField(currentField, fieldVisible);
-					currentColumn = temp->query()->expandedOrInternalField( temp->query()->fieldsExpanded().count() - 1 );
+					currentColumn = temp->query()->expandedOrInternalField( 
+						temp->query()->fieldsExpanded().count() - 1 );
 					if (fieldVisible)
 						fieldsFound = true;
 					if (!alias.isEmpty())
@@ -468,7 +493,8 @@ KexiQueryDesignerGuiEditor::buildSchema(QString *errMsg)
 		return false;
 	}
 	if (whereExpr)
-		kexipluginsdbg << "KexiQueryDesignerGuiEditor::buildSchema(): setting CRITERIA: " << whereExpr->debugString() << endl;
+		kexipluginsdbg << "KexiQueryDesignerGuiEditor::buildSchema(): setting CRITERIA: " 
+			<< whereExpr->debugString() << endl;
 
 	//set always, because if whereExpr==NULL,
 	//this will clear prev. expr
@@ -485,25 +511,47 @@ KexiQueryDesignerGuiEditor::buildSchema(QString *errMsg)
 			detailsTable->schema()->table()->field(it.current()->detailsField()) );
 	}
 
-	// Add sorting information (ORDER BY) - we can do that only now once 
-	//  all QueryColumnInfo items are instantiated
+	// Add sorting information (ORDER BY) - we can do that only now
+	//  after all QueryColumnInfo items are instantiated
 	KexiDB::OrderByColumnList orderByColumns;
 	it = d->data->iterator();
-	for (uint i=0; i<count && it.current(); ++it, i++) {
+	int fieldNumber = -1; //field number (empty rows are omitted)
+	for (uint i=0/*row number*/; i<count && it.current(); ++it, i++) {
 		KoProperty::Set *set = d->sets->at(i);
 		if (!set)
 			continue;
-		KexiDB::Field *currentField = temp->query()->field( i );
+		fieldNumber++;
+		KexiDB::Field *currentField = 0;
+		KexiDB::QueryColumnInfo *currentColumn = 0;
+		QString sortingString( (*set)["sorting"].value().toString() );
+		if (sortingString!="ascending" && sortingString!="descending")
+			continue;
+		if (!(*set)["visible"].value().toBool()) {
+			// this row defines invisible field but contains sorting information,
+			// what means KexiDB::Field should be used as a reference for this sorting
+			// Note1: alias is not supported here.
+
+			// Try to find a field (not mentioned after SELECT):
+			currentField = temp->query()->findTableField( (*set)["field"].value().toString() );
+			if (!currentField) {
+				kexipluginswarn << "KexiQueryDesignerGuiEditor::buildSchema(): NO FIELD '" 
+					<< (*set)["field"].value().toString()
+					<< " available for sorting" << endl;
+				continue;
+			}
+			orderByColumns.appendField(*currentField, sortingString=="ascending");
+			continue;
+		}
+		currentField = temp->query()->field( (uint)fieldNumber );
 		if (!currentField || currentField->isExpression() || currentField->isQueryAsterisk())
 //! @todo support expressions here
 			continue;
-//! @todo ok, but not for expresions
+//! @todo ok, but not for expressions
 		QString aliasString( (*set)["alias"].value().toString() );
-		KexiDB::QueryColumnInfo *currentColumn = temp->query()->columnInfo( 
+		currentColumn = temp->query()->columnInfo( 
 			(*set)["table"].value().toString() + "."
 			+ (aliasString.isEmpty() ? currentField->name() : aliasString) );
-		QString sortingString( (*set)["sorting"].value().toString() );
-		if (currentField && currentColumn && (sortingString=="ascending" || sortingString=="descending")) {
+		if (currentField && currentColumn) {
 			if (currentColumn->visible)
 				orderByColumns.appendColumn(*currentColumn, sortingString=="ascending");
 			else if (currentColumn->field)
@@ -569,12 +617,14 @@ KexiQueryDesignerGuiEditor::beforeSwitchTo(int mode, bool &dontStore)
 tristate
 KexiQueryDesignerGuiEditor::afterSwitchFrom(int mode)
 {
+	const bool was_dirty = dirty();
+	KexiDB::Connection *conn = parentDialog()->mainWin()->project()->dbConnection();
 	if (mode==Kexi::NoViewMode || (mode==Kexi::DataViewMode && !tempData()->query())) {
 		//this is not a SWITCH but a fresh opening in this view mode
 		if (!m_dialog->neverSaved()) {
 			if (!loadLayout()) {
 				//err msg
-				parentDialog()->setStatus(parentDialog()->mainWin()->project()->dbConnection(),
+				parentDialog()->setStatus(conn,
 					i18n("Query definition loading failed."),
 					i18n("Query design may be corrupted so it could not be opened even in text view.\n"
 						"You can delete the query and create it again."));
@@ -585,12 +635,21 @@ KexiQueryDesignerGuiEditor::afterSwitchFrom(int mode)
 			// and then KexiQueryPart::loadSchemaData() doesn't allocate QuerySchema object
 			// do we're carefully looking at parentDialog()->schemaData()
 			KexiDB::QuerySchema * q = dynamic_cast<KexiDB::QuerySchema *>(parentDialog()->schemaData());
-			if (q)
-				showFieldsForQuery( q );
-			//todo: load global query properties
+			if (q) {
+				KexiDB::ResultInfo result;
+				showFieldsForQuery( q, result );
+				if (!result.success) {
+					parentDialog()->setStatus(&result, i18n("Query definition loading failed."));
+					tempData()->proposeOpeningInTextViewModeBecauseOfProblems = true;
+					return false;
+				}
+			}
+//! @todo load global query properties
 		}
 	}
-	else if (mode==Kexi::TextViewMode) {
+	else if (mode==Kexi::TextViewMode || mode==Kexi::DataViewMode) {
+		// Switch from text or data view. In the second case, the design could be changed as well
+		// because there could be changes made in the text view before switching to the data view.
 		if (tempData()->queryChangedInPreviousView) {
 			//previous view changed query data
 			//-clear and regenerate GUI items
@@ -600,15 +659,21 @@ KexiQueryDesignerGuiEditor::afterSwitchFrom(int mode)
 				//there is a query schema to show
 				showTablesForQuery( tempData()->query() );
 				//-show fields
-				showFieldsAndRelationsForQuery( tempData()->query() );
+				KexiDB::ResultInfo result;
+				showFieldsAndRelationsForQuery( tempData()->query(), result );
+				if (!result.success) {
+					parentDialog()->setStatus(&result, i18n("Query definition loading failed."));
+					return false;
+				}
 			}
 			else {
 				d->relations->clear();
 			}
 		}
-		//todo: load global query properties
+//! @todo load global query properties
 	}
-	else if (mode==Kexi::DataViewMode) {
+	
+	if (mode==Kexi::DataViewMode) {
 		//this is just a SWITCH from data view
 		//set cursor if needed:
 		if (d->dataTable->dataAwareObject()->currentRow()<0
@@ -620,6 +685,8 @@ KexiQueryDesignerGuiEditor::afterSwitchFrom(int mode)
 	}
 	tempData()->queryChangedInPreviousView = false;
 	setFocus(); //to allow shared actions proper update
+	if (!was_dirty)
+		setDirty(false);
 	return true;
 }
 
@@ -676,7 +743,6 @@ tristate KexiQueryDesignerGuiEditor::storeData(bool dontAsk)
 	return res;
 }
 
-//void KexiQueryDesignerGuiEditor::showTablesAndConnectionsForQuery(KexiDB::QuerySchema *query)
 void KexiQueryDesignerGuiEditor::showTablesForQuery(KexiDB::QuerySchema *query)
 {
 //replaced by code below that preserves geometries d->relations->clear();
@@ -705,27 +771,29 @@ void KexiQueryDesignerGuiEditor::addConnection(
 	d->relations->addConnection( conn );
 }
 
-void KexiQueryDesignerGuiEditor::showFieldsForQuery(KexiDB::QuerySchema *query)
+void KexiQueryDesignerGuiEditor::showFieldsForQuery(KexiDB::QuerySchema *query, KexiDB::ResultInfo& result)
 {
-	showFieldsOrRelationsForQueryInternal(query, true, false);
+	showFieldsOrRelationsForQueryInternal(query, true, false, result);
 }
 
-void KexiQueryDesignerGuiEditor::showRelationsForQuery(KexiDB::QuerySchema *query)
+void KexiQueryDesignerGuiEditor::showRelationsForQuery(KexiDB::QuerySchema *query, KexiDB::ResultInfo& result)
 {
-	showFieldsOrRelationsForQueryInternal(query, false, true);
+	showFieldsOrRelationsForQueryInternal(query, false, true, result);
 }
 
-void KexiQueryDesignerGuiEditor::showFieldsAndRelationsForQuery(KexiDB::QuerySchema *query)
+void KexiQueryDesignerGuiEditor::showFieldsAndRelationsForQuery(KexiDB::QuerySchema *query, 
+	KexiDB::ResultInfo& result)
 {
-	showFieldsOrRelationsForQueryInternal(query, true, true);
+	showFieldsOrRelationsForQueryInternal(query, true, true, result);
 }
 
 void KexiQueryDesignerGuiEditor::showFieldsOrRelationsForQueryInternal(
-	KexiDB::QuerySchema *query, bool showFields, bool showRelations)
+	KexiDB::QuerySchema *query, bool showFields, bool showRelations, KexiDB::ResultInfo& result)
 {
+	result.clear();
 	const bool was_dirty = dirty();
 
-	//1. Show explicity declared relations:
+	//1. Show explicitly declared relations:
 	if (showRelations) {
 		KexiDB::Relationship *rel;
 		for (KexiDB::Relationship::ListIterator it(*query->relationships());
@@ -855,7 +923,7 @@ void KexiQueryDesignerGuiEditor::showFieldsOrRelationsForQueryInternal(
 			}
 		}
 		//create new row data
-		KexiTableItem *newItem = createNewRow(tableName, fieldName);
+		KexiTableItem *newItem = createNewRow(tableName, fieldName, true /* visible*/);
 		if (criteriaExpr) {
 //! @todo fix for !INFIX operators
 			if (criteriaExpr->token()=='=')
@@ -872,54 +940,59 @@ void KexiQueryDesignerGuiEditor::showFieldsOrRelationsForQueryInternal(
 		if (!criteriaString.isEmpty())
 			set["criteria"].setValue( criteriaString, false );
 		if (field->isExpression()) {
-			(*newItem)[COLUMN_ID_COLUMN] = criteriaString;
-			d->data->clearRowEditBuffer();
-			d->data->updateRowEditBuffer(newItem, COLUMN_ID_COLUMN,
-				QVariant(columnAlias + ": " + field->expression()->toString()));
-			d->data->saveRowChanges(*newItem, true);
+//			(*newItem)[COLUMN_ID_COLUMN] = ;
+			if (!d->changeSingleCellValue(*newItem, COLUMN_ID_COLUMN, 
+					QVariant(columnAlias + ": " + field->expression()->toString()), &result))
+				return; //problems with setting column expression
 		}
 	}
 
 	//4. show ORDER BY information
+	d->data->clearRowEditBuffer();
 	KexiDB::OrderByColumnList &orderByColumns = query->orderByColumnList();
-//	QPtrDict<KexiDB::OrderByColumn> orderByDictForFields;
-//	QPtrDict<KexiDB::OrderByColumn> orderByDictForColumns;
 	QMap<KexiDB::QueryColumnInfo*,int> columnsOrder( 
 		query->columnsOrder(KexiDB::QuerySchema::UnexpandedListWithoutAsterisks) );
 	for (KexiDB::OrderByColumn::ListConstIterator orderByColumnsIt( orderByColumns.constBegin() );
 		orderByColumnsIt!=orderByColumns.constEnd(); ++orderByColumnsIt)
 	{
 		KexiDB::QueryColumnInfo *column = (*orderByColumnsIt).column();
+		KexiTableItem *rowItem = 0;
+		KoProperty::Set *rowPropertySet = 0;
 		if (column) {
 			//sorting for visible column
 			if (column->visible) {
 				if (columnsOrder.contains(column)) {
 					const int columnPosition = columnsOrder[ column ];
-					KexiTableItem *rowItem = d->data->at( columnPosition );
-					KoProperty::Set *rowPropertySet = d->sets->at( columnPosition );
-					if (rowItem && rowPropertySet) {
-						kexipluginsdbg << "KexiQueryDesignerGuiEditor::showFieldsOrRelationsForQueryInternal():\n\t"
-							"Setting \"" << (*orderByColumnsIt).debugString() << "\" sorting for row #" 
-							<< columnPosition<< endl;
-						//(*rowPropertySet)["sorting"].setValue(
-							//QString((*orderByColumnsIt).ascending() ? "ascending" : "descending") );
-						d->data->clearRowEditBuffer();
-						d->data->updateRowEditBuffer(rowItem, COLUMN_ID_SORTING,
-							(*orderByColumnsIt).ascending() ? 1 : 2); // this will automatically update "sorting" property
-						                                             // in slotBeforeCellChanged()
-						d->data->saveRowChanges(*rowItem, true);
-						(*rowPropertySet)["sorting"].clearModifiedFlag(); // this property should look "fresh"
-//						d->data->rowEditBuffer()->debug();
-					}
-//					query->field(columnPosition);
+					rowItem = d->data->at( columnPosition );
+					rowPropertySet = d->sets->at( columnPosition );
+					kexipluginsdbg << "KexiQueryDesignerGuiEditor::showFieldsOrRelationsForQueryInternal():\n\t"
+						"Setting \"" << (*orderByColumnsIt).debugString() << "\" sorting for row #" 
+						<< columnPosition << endl;
 				}
 			}
-//				orderByDictForColumns.replace( (void*)(*orderByColumnsIt).column(), &(*orderByColumnsIt) );
-	//		else
-		//		orderByDictForFields.replace( (void*)(*orderByColumnsIt).column()->field, &(*orderByColumnsIt) );
 		}
-		else if ((*orderByColumnsIt).field()) {//this will be presented as invisible field
-//			orderByDictForFields.replace( (void*)(*orderByColumnsIt).field(), &(*orderByColumnsIt) );
+		else if ((*orderByColumnsIt).field()) {
+			//this will be presented as invisible field: create new row
+			field = (*orderByColumnsIt).field();
+			QString tableName( field->table() ? field->table()->name() : QString::null );
+			rowItem = createNewRow( tableName, field->name(), false /* !visible*/);
+			d->dataTable->dataAwareObject()->insertItem(rowItem, row_num);
+			rowPropertySet = createPropertySet( row_num, tableName, field->name(), true /*newOne*/ );
+			propertySetSwitched();
+			kexipluginsdbg << "KexiQueryDesignerGuiEditor::showFieldsOrRelationsForQueryInternal():\n\t"
+				"Setting \"" << (*orderByColumnsIt).debugString() << "\" sorting for invisible field " 
+				<< field->name() << ", table " << tableName << " -row #" << row_num << endl;
+			row_num++;
+		}
+		//alter sorting for either existing or new row
+		if (rowItem && rowPropertySet) {
+			d->data->updateRowEditBuffer(rowItem, COLUMN_ID_SORTING,
+				(*orderByColumnsIt).ascending() ? 1 : 2); // this will automatically update "sorting" property
+						                                        // in slotBeforeCellChanged()
+			d->data->saveRowChanges(*rowItem, true);
+			(*rowPropertySet)["sorting"].clearModifiedFlag(); // this property should look "fresh"
+			if (!rowItem->at(COLUMN_ID_VISIBLE).toBool()) //update
+				(*rowPropertySet)["visible"].setValue(QVariant(false,0), false/*rememberOldValue*/); 
 		}
 	}
 
@@ -1007,7 +1080,12 @@ bool KexiQueryDesignerGuiEditor::loadLayout()
 		KexiDB::QuerySchema * q =	dynamic_cast<KexiDB::QuerySchema *>(parentDialog()->schemaData());
 		if (q) {
 			showTablesForQuery( q );
-			showRelationsForQuery( q );
+			KexiDB::ResultInfo result;
+			showRelationsForQuery( q, result );
+			if (!result.success) {
+				parentDialog()->setStatus(&result, i18n("Query definition loading failed."));
+				return false;
+			}
 		}
 		return true;
 	}
@@ -1059,8 +1137,9 @@ bool KexiQueryDesignerGuiEditor::storeLayout()
 	if (m_dialog->schemaData()) //set this instance as obsolete (only if it's stored)
 		dbConn->setQuerySchemaObsolete( m_dialog->schemaData()->name() );
 
-	QString sqlText = dbConn->selectStatement(
-		*temp->query(), KexiDB::Driver::EscapeKexi|KexiDB::Driver::EscapeAsNecessary );
+	KexiDB::Connection::SelectStatementOptions options;
+	options.identifierEscaping = KexiDB::Driver::EscapeKexi|KexiDB::Driver::EscapeAsNecessary;
+	QString sqlText = dbConn->selectStatement( *temp->query(), options );
 	if (!storeDataBlock( sqlText, "sql" )) {
 		return false;
 	}
@@ -1108,10 +1187,8 @@ KexiTableItem*
 KexiQueryDesignerGuiEditor::createNewRow(const QString& tableName, const QString& fieldName,
 	bool visible) const
 {
-	KexiTableItem *newItem = d->data->createItem(); //new KexiTableItem(d->data->columnsCount());
+	KexiTableItem *newItem = d->data->createItem();
 	QString key;
-//	if (!alias.isEmpty())
-//		key=alias+": ";
 	if (tableName=="*")
 		key="*";
 	else {
@@ -1123,7 +1200,7 @@ KexiQueryDesignerGuiEditor::createNewRow(const QString& tableName, const QString
 	(*newItem)[COLUMN_ID_TABLE]=tableName;
 	(*newItem)[COLUMN_ID_VISIBLE]=QVariant(visible, 1);
 #ifndef KEXI_NO_QUERY_TOTALS
-	(*newItem)[COLUMN_ID_TOTALS]=QVariant(0);//totals
+	(*newItem)[COLUMN_ID_TOTALS]=QVariant(0);
 #endif
 	return newItem;
 }
@@ -1147,13 +1224,20 @@ KexiQueryDesignerGuiEditor::slotDroppedAtRow(KexiTableItem * /*item*/, int /*row
 	if (!KexiFieldDrag::decodeSingle(ev,sourceMimeType,srcTable,srcField))
 		return;
 	//insert new row at specific place
-	newItem = createNewRow(srcTable, srcField);
+	newItem = createNewRow(srcTable, srcField, true /* visible*/);
 	d->droppedNewItem = newItem;
 	d->droppedNewTable = srcTable;
 	d->droppedNewField = srcField;
 	//TODO
 }
 
+void KexiQueryDesignerGuiEditor::slotNewItemAppendedForAfterDeletingInSpreadSheetMode()
+{
+	KexiTableItem *item = d->data->last();
+	if (item)
+		item->at(COLUMN_ID_VISIBLE) = QVariant(false, 0); //the same init as in initTableRows()
+}
+
 void KexiQueryDesignerGuiEditor::slotRowInserted(KexiTableItem* item, uint row, bool /*repaint*/)
 {
 	if (d->droppedNewItem && d->droppedNewItem==item) {
@@ -1249,14 +1333,17 @@ KexiQueryDesignerGuiEditor::parseExpressionString(const QString& fullString, int
 
 	KexiDB::BaseExpr *valueExpr = 0;
 	QRegExp re;
-	if (str.length()>=2
-		&& (
-		(str.startsWith("\"") && str.endsWith("\""))
+	if (str.length()>=2 &&
+		(
+		   (str.startsWith("\"") && str.endsWith("\""))
 		|| (str.startsWith("'") && str.endsWith("'")))
 		)
 	{
 		valueExpr = new KexiDB::ConstExpr(CHARACTER_STRING_LITERAL, str.mid(1,str.length()-2));
 	}
+	else if (str.startsWith("[") && str.endsWith("]")) {
+		valueExpr = new KexiDB::QueryParameterExpr(str.mid(1,str.length()-2));
+	}
 	else if ((re = QRegExp("(\\d{1,4})-(\\d{1,2})-(\\d{1,2})")).exactMatch( str ))
 	{
 			valueExpr = new KexiDB::ConstExpr(DATE_CONST, QDate::fromString(
@@ -1333,6 +1420,7 @@ void KexiQueryDesignerGuiEditor::slotBeforeCellChanged(KexiTableItem *item, int
 		if (newValue.isNull()) {
 			d->data->updateRowEditBuffer(item, COLUMN_ID_TABLE, QVariant(), false/*!allowSignals*/);
 			d->data->updateRowEditBuffer(item, COLUMN_ID_VISIBLE, QVariant(false,1));//invisible
+			d->data->updateRowEditBuffer(item, COLUMN_ID_SORTING, QVariant());
 #ifndef KEXI_NO_QUERY_TOTALS
 			d->data->updateRowEditBuffer(item, COLUMN_ID_TOTALS, QVariant());//remove totals
 #endif
@@ -1500,7 +1588,7 @@ void KexiQueryDesignerGuiEditor::slotBeforeCellChanged(KexiTableItem *item, int
 			result->success = false;
 			result->allowToDiscardChanges = true;
 			result->column = colnum;
-			result->msg = futureI18n("Could not set sorting for multiple columns (%1)")
+			result->msg = i18n("Could not set sorting for multiple columns (%1)")
 				.arg(table=="*" ? table : (table+".*"));
 		}
 	}
@@ -1575,7 +1663,7 @@ void KexiQueryDesignerGuiEditor::slotTableFieldDoubleClicked(
 		;
 	row_num++; //after
 	//add row
-	KexiTableItem *newItem = createNewRow(table->name(), fieldName);
+	KexiTableItem *newItem = createNewRow(table->name(), fieldName, true /* visible*/);
 	d->dataTable->dataAwareObject()->insertItem(newItem, row_num);
 	d->dataTable->dataAwareObject()->setCursorPosition(row_num, 0);
 	//create buffer
