@@ -1,5 +1,5 @@
 /* This file is part of the KDE project
-   Copyright (C) 2004-2006 Jaroslaw Staniek <js@iidea.pl>
+   Copyright (C) 2004-2007 Jaroslaw Staniek <js@iidea.pl>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -19,6 +19,8 @@
 
 #include "kexitabledesignerview.h"
 #include "kexitabledesignerview_p.h"
+#include "kexilookupcolumnpage.h"
+#include "kexitabledesignercommands.h"
 
 #include <qlayout.h>
 #include <qlabel.h>
@@ -30,6 +32,7 @@
 #include <kaction.h>
 #include <kpopupmenu.h>
 #include <kmessagebox.h>
+#include <kiconeffect.h>
 
 #include <koproperty/set.h>
 #include <koproperty/utils.h>
@@ -40,6 +43,7 @@
 #include <kexidb/utils.h>
 #include <kexidb/roweditbuffer.h>
 #include <kexidb/error.h>
+#include <kexidb/lookupfieldschema.h>
 #include <kexiutils/identifier.h>
 #include <kexiproject.h>
 #include <keximainwindow.h>
@@ -48,16 +52,9 @@
 #include <kexiutils/utils.h>
 #include <kexidialogbase.h>
 #include <kexitableview.h>
-#include "kexitabledesignercommands.h"
 
 //#define MAX_FIELDS 101 //nice prime number
 
-//! indices for table columns
-#define COLUMN_ID_PK 0
-#define COLUMN_ID_CAPTION 1
-#define COLUMN_ID_TYPE 2
-#define COLUMN_ID_DESC 3
-
 //! used only for BLOBs
 #define DEFAULT_OBJECT_TYPE_VALUE "image"
 
@@ -116,28 +113,31 @@ KexiTableDesignerView::KexiTableDesignerView(KexiMainWindow *win, QWidget *paren
 	KexiCustomPropertyFactory::init();
 
 	KexiDB::Connection *conn = mainWin()->project()->dbConnection();
+	d->view = dynamic_cast<KexiTableView*>(mainWidget());
 
 	d->data = new KexiTableViewData();
 	if (conn->isReadOnly())
 		d->data->setReadOnly(true);
 	d->data->setInsertingEnabled( false );
 
-	KexiTableViewColumn *col = new KexiTableViewColumn("pk", KexiDB::Field::Text, i18n("Primary Key", "PK"),
-		i18n("Describes primary key for the field."));
+	KexiTableViewColumn *col = new KexiTableViewColumn("pk", KexiDB::Field::Text, QString::null,
+		i18n("Additional information about the field"));
+	col->setIcon( KexiUtils::colorizeIconToTextColor( SmallIcon("info"), d->view->palette() ) );
+	col->setHeaderTextVisible(false);
 	col->field()->setSubType("KIcon");
 	col->setReadOnly(true);
 	d->data->addColumn( col );
 
 //	col = new KexiTableViewColumn("name", KexiDB::Field::Text, i18n("Field Name"),
 	col = new KexiTableViewColumn("caption", KexiDB::Field::Text, i18n("Field Caption"),
-		i18n("Describes name for the field."));
+		i18n("Describes caption for the field"));
 //	KexiUtils::Validator *vd = new KexiUtils::IdentifierValidator();
 //	vd->setAcceptsEmptyValue(true);
 //	col->setValidator( vd );
 	d->data->addColumn( col );
 
 	col = new KexiTableViewColumn("type", KexiDB::Field::Enum, i18n("Data Type"),
-		i18n("Describes data type for the field."));
+		i18n("Describes data type for the field"));
 	d->data->addColumn( col );
 
 #ifdef KEXI_NO_BLOB_FIELDS
@@ -155,12 +155,9 @@ KexiTableDesignerView::KexiTableDesignerView(KexiMainWindow *win, QWidget *paren
 	col->field()->setEnumHints(types);
 
 	d->data->addColumn( col = new KexiTableViewColumn("comments", KexiDB::Field::Text, i18n("Comments"),
-		i18n("Describes additional comments for the field.")) );
-
-	d->view = dynamic_cast<KexiTableView*>(mainWidget());
+		i18n("Describes additional comments for the field")) );
 
 	d->view->setSpreadSheetMode();
-//	setFocusProxy(d->view);
 
 	connect(d->data, SIGNAL(aboutToChangeCell(KexiTableItem*,int,QVariant&,KexiDB::ResultInfo*)),
 		this, SLOT(slotBeforeCellChanged(KexiTableItem*,int,QVariant&,KexiDB::ResultInfo*)));
@@ -226,12 +223,22 @@ void KexiTableDesignerView::initData()
 		for(int i=0; i < tableFieldCount; i++) {
 			KexiDB::Field *field = tempData()->table->field(i);
 			KexiTableItem *item = d->data->createItem(); //new KexiTableItem(0);
-			(*item)[0] = field->isPrimaryKey() ? "key" : "";
-			if (field->isPrimaryKey())
+			if (field->isPrimaryKey()) {
+				(*item)[COLUMN_ID_ICON] = "key";
 				d->primaryKeyExists = true;
-			(*item)[1] = field->captionOrName();
-			(*item)[2] = field->typeGroup()-1; //-1 because type groups are counted from 1
-			(*item)[3] = field->description();
+			}
+			else {
+				KexiDB::LookupFieldSchema *lookupFieldSchema
+					= field->table() ? field->table()->lookupFieldSchema(*field) : 0;
+				if (lookupFieldSchema && lookupFieldSchema->rowSource().type()!=KexiDB::LookupFieldSchema::RowSource::NoType
+					&& !lookupFieldSchema->rowSource().name().isEmpty())
+				{
+					(*item)[COLUMN_ID_ICON] = "combo";
+				}
+			}
+			(*item)[COLUMN_ID_CAPTION] = field->captionOrName();
+			(*item)[COLUMN_ID_TYPE] = field->typeGroup()-1; //-1 because type groups are counted from 1
+			(*item)[COLUMN_ID_DESC] = field->description();
 			d->data->append(item);
 
 //later!			createPropertySet( i, field );
@@ -260,7 +267,7 @@ void KexiTableDesignerView::initData()
 	}
 
 	//column widths
-	d->view->setColumnWidth(COLUMN_ID_PK, IconSize( KIcon::Small ) + 10);
+	d->view->setColumnWidth(COLUMN_ID_ICON, IconSize( KIcon::Small ) + 10);
 	d->view->adjustColumnWidthToContents(COLUMN_ID_CAPTION); //adjust column width
 	d->view->setColumnWidth(COLUMN_ID_TYPE, d->maxTypeNameTextWidth + 2 * d->view->rowHeight());
 	d->view->setColumnStretchEnabled( true, COLUMN_ID_DESC ); //last column occupies the rest of the area
@@ -270,6 +277,7 @@ void KexiTableDesignerView::initData()
 
 	setDirty(false);
 	d->view->setCursorPosition(0, COLUMN_ID_CAPTION); //set @ name column
+	propertySetSwitched();
 }
 
 //! Gets subtype strings and names for type \a fieldType
@@ -310,8 +318,14 @@ KexiTableDesignerView::createPropertySet( int row, const KexiDB::Field& field, b
 	//meta-info for property editor
 	set->addProperty(prop = new KoProperty::Property("this:classString", i18n("Table field")) );
 	prop->setVisible(false);
-//! \todo add table_field icon (add	buff->addProperty(prop = new KexiProperty("this:iconName", "table_field") );
-//	prop->setVisible(false);
+	set->addProperty(prop = new KoProperty::Property("this:iconName", 
+//! \todo add table_field icon 
+		"lineedit" //"table_field"
+	));
+	prop->setVisible(false);
+	set->addProperty(prop = new KoProperty::Property("this:useCaptionAsObjectName", 
+		QVariant(true, 1), QString::null)); //we want "caption" to be displayed in the header, not name
+	prop->setVisible(false);
 
 	//name
 	set->addProperty(prop 
@@ -385,30 +399,60 @@ KexiTableDesignerView::createPropertySet( int row, const KexiDB::Field& field, b
 
 	set->addProperty( prop 
 		= new KoProperty::Property("defaultValue", field.defaultValue(), i18n("Default Value"),
-			QString::null, (KoProperty::PropertyType)field.variantType()) );
+			QString::null, 
+//! @todo use "Variant" type here when supported by KoProperty
+			(KoProperty::PropertyType)field.variantType()) );
 	prop->setOption("3rdState", i18n("None"));
 //	prop->setVisible(false);
 
-	set->addProperty(prop 
+	set->addProperty( prop 
 		= new KoProperty::Property("primaryKey", QVariant(field.isPrimaryKey(), 4), i18n("Primary Key")));
 	prop->setIcon("key");
 
-	set->addProperty(
-		new KoProperty::Property("unique", QVariant(field.isUniqueKey(), 4), i18n("Unique")));
+	set->addProperty( prop
+		= new KoProperty::Property("unique", QVariant(field.isUniqueKey(), 4), i18n("Unique")));
 
-	set->addProperty(
-		new KoProperty::Property("notNull", QVariant(field.isNotNull(), 4), i18n("Required")));
+	set->addProperty( prop
+		= new KoProperty::Property("notNull", QVariant(field.isNotNull(), 4), i18n("Required")));
 	
-	set->addProperty(
-		new KoProperty::Property("allowEmpty", QVariant(!field.isNotEmpty(), 4), i18n("Allow Zero\nSize")));
+	set->addProperty( prop
+		= new KoProperty::Property("allowEmpty", QVariant(!field.isNotEmpty(), 4), i18n("Allow Zero\nSize")));
 
-	set->addProperty(prop 
+	set->addProperty( prop
 		= new KoProperty::Property("autoIncrement", QVariant(field.isAutoIncrement(), 4), i18n("Autonumber")));
 	prop->setIcon("autonumber");
 
-	set->addProperty(
-		new KoProperty::Property("indexed", QVariant(field.isIndexed(), 4), i18n("Indexed")));
+	set->addProperty( prop
+		= new KoProperty::Property("indexed", QVariant(field.isIndexed(), 4), i18n("Indexed")));
 
+	//- properties related to lookup columns (used and set by the "lookup column" tab in the property pane)
+	KexiDB::LookupFieldSchema *lookupFieldSchema = field.table() ? field.table()->lookupFieldSchema(field) : 0;
+	set->addProperty( prop = new KoProperty::Property("rowSource", 
+		lookupFieldSchema ? lookupFieldSchema->rowSource().name() : QString::null, i18n("Row Source")));
+	prop->setVisible(false);
+
+	set->addProperty( prop = new KoProperty::Property("rowSourceType", 
+		lookupFieldSchema ? lookupFieldSchema->rowSource().typeName() : QString::null, i18n("Row Source\nType")));
+	prop->setVisible(false);
+
+	set->addProperty( prop
+		= new KoProperty::Property("boundColumn", 
+		lookupFieldSchema ? lookupFieldSchema->boundColumn() : -1, i18n("Bound Column")));
+	prop->setVisible(false);
+	
+//! @todo this is backward-compatible code for "single visible column" implementation
+//!       for multiple columns, only the first is displayed, so there is a data loss is GUI is used
+//!       -- special koproperty editor needed
+	int visibleColumn = -1;
+	if (lookupFieldSchema && !lookupFieldSchema->visibleColumns().isEmpty())
+		visibleColumn = lookupFieldSchema->visibleColumns().first();
+	set->addProperty( prop
+		= new KoProperty::Property("visibleColumn", visibleColumn, i18n("Visible Column")));
+	prop->setVisible(false);
+
+//! @todo support columnWidths(), columnHeadersVisible(), maximumListRows(), limitToList(), displayWidget()
+
+	//----
 	d->updatePropertiesVisibility(field.type(), *set);
 
 	connect(set, SIGNAL(propertyChanged(KoProperty::Set&, KoProperty::Property&)),
@@ -473,7 +517,7 @@ void KexiTableDesignerView::switchPrimaryKey(KoProperty::Set &propertySet,
 		if (d->view->selectedItem()) {
 			//show key in the table
 			d->view->data()->clearRowEditBuffer();
-			d->view->data()->updateRowEditBuffer(d->view->selectedItem(), COLUMN_ID_PK, 
+			d->view->data()->updateRowEditBuffer(d->view->selectedItem(), COLUMN_ID_ICON, 
 				QVariant(set ? "key" : ""));
 			d->view->data()->saveRowChanges(*d->view->selectedItem(), true);
 		}
@@ -500,7 +544,7 @@ void KexiTableDesignerView::switchPrimaryKey(KoProperty::Set &propertySet,
 			d->view->data()->clearRowEditBuffer();
 			KexiTableItem *item = d->view->itemAt(i);
 			if (item) {
-				d->view->data()->updateRowEditBuffer(item, COLUMN_ID_PK, QVariant());
+				d->view->data()->updateRowEditBuffer(item, COLUMN_ID_ICON, QVariant());
 				d->view->data()->saveRowChanges(*item, true);
 			}
 		}
@@ -660,7 +704,7 @@ void KexiTableDesignerView::slotBeforeCellChanged(
 		if (newValue.isNull()) {
 			//'type' col will be cleared: clear all other columns as well
 			d->slotBeforeCellChanged_enabled = false;
-				d->view->data()->updateRowEditBuffer(item, COLUMN_ID_PK, QVariant());
+				d->view->data()->updateRowEditBuffer(item, COLUMN_ID_ICON, QVariant());
 				d->view->data()->updateRowEditBuffer(item, COLUMN_ID_CAPTION, QVariant(QString::null));
 				d->view->data()->updateRowEditBuffer(item, COLUMN_ID_DESC, QVariant());
 			d->slotBeforeCellChanged_enabled = true;
@@ -751,7 +795,7 @@ void KexiTableDesignerView::slotBeforeCellChanged(
 			//primary keys require big int, so if selected type is not integer- remove PK
 			if (fieldTypeGroup != KexiDB::Field::IntegerGroup) {
 				/*not needed, line below will do the work
-				d->view->data()->updateRowEditBuffer(item, COLUMN_ID_PK, QVariant());
+				d->view->data()->updateRowEditBuffer(item, COLUMN_ID_ICON, QVariant());
 				d->view->data()->saveRowChanges(*item); */
 				//set["primaryKey"] = QVariant(false, 1);
 				d->setPropertyValueIfNeeded( set, "primaryKey", QVariant(false, 1), changeDataTypeCommand );
@@ -890,6 +934,16 @@ void KexiTableDesignerView::slotPropertyChanged(KoProperty::Set& set, KoProperty
 		setPrimaryKey = property.value().toBool();
 	}
 
+	// update "lookup column" icon
+	if (pname=="rowSource" || pname=="rowSourceType") {
+//! @todo indicate invalid definitions of lookup columns as well using a special icon 
+//!       (e.g. due to missing data source)
+		const int row = d->sets->findRowForPropertyValue("uid", set["uid"].value().toInt());
+		KexiTableItem *item = d->view->itemAt(row);
+		if (item)
+			d->updateIconForItem(*item, set);
+	}
+
 	//setting autonumber requires setting PK as well
 	CommandGroup *setAutonumberCommand = 0;
 	CommandGroup *toplevelCommand = 0;
@@ -930,7 +984,7 @@ void KexiTableDesignerView::slotPropertyChanged(KoProperty::Set& set, KoProperty
 		}
 	}
 
-	//clear PK when these properies were set to false:
+	//clear PK when these properties were set to false:
 	if ((pname=="indexed" || pname=="unique" || pname=="notNull") 
 		&& set["primaryKey"].value().toBool() && property.value().toBool()==false)
 	{
@@ -1095,7 +1149,7 @@ void KexiTableDesignerView::slotAboutToDeleteRow(
 {
 	Q_UNUSED(result)
 	Q_UNUSED(repaint)
-	if (item[COLUMN_ID_PK].toString()=="key")
+	if (item[COLUMN_ID_ICON].toString()=="key")
 		d->primaryKeyExists = false;
 
 	if (d->addHistoryCommand_in_slotAboutToDeleteRow_enabled) {
@@ -1117,9 +1171,10 @@ KexiDB::Field * KexiTableDesignerView::buildField( const KoProperty::Set &set )
 	//remove internal values, to avoid creating custom field's properties
 	QMap<QCString, QVariant>::Iterator it = values.begin();
 	KexiDB::Field *field = new KexiDB::Field();
+
 	while (it!=values.end()) {
 		const QString propName( it.key() );
-		if (propName=="subType" || propName=="uid" || propName=="newrow" || propName.startsWith("this:")
+		if (d->internalPropertyNames.find(propName.latin1()) || propName.startsWith("this:")
 			|| (/*sanity*/propName=="objectType" && KexiDB::Field::BLOB != KexiDB::intToFieldType( set["type"].value().toInt() )))
 		{
 			QMap<QCString, QVariant>::Iterator it_tmp = it;
@@ -1270,6 +1325,28 @@ tristate KexiTableDesignerView::buildSchema(KexiDB::TableSchema &schema, bool be
 			if (!f)
 				continue; //hmm?
 			schema.addField(f);
+			if (!(*s)["rowSource"].value().toString().isEmpty() && !(*s)["rowSourceType"].value().toString().isEmpty()) {
+				//add lookup column
+				KexiDB::LookupFieldSchema *lookupFieldSchema = new KexiDB::LookupFieldSchema();
+				lookupFieldSchema->rowSource().setTypeByName( (*s)["rowSourceType"].value().toString() );
+				lookupFieldSchema->rowSource().setName( (*s)["rowSource"].value().toString() );
+				lookupFieldSchema->setBoundColumn( (*s)["boundColumn"].value().toInt() );
+//! @todo this is backward-compatible code for "single visible column" implementation
+//!       for multiple columns, only the first is displayed, so there is a data loss is GUI is used
+//!       -- special koproperty editor needed
+				QValueList<uint> visibleColumns;
+				const int visibleColumn = (*s)["visibleColumn"].value().toInt();
+				if (visibleColumn >= 0)
+					visibleColumns.append( (uint)visibleColumn );
+				lookupFieldSchema->setVisibleColumns( visibleColumns );
+//! @todo support columnWidths(), columnHeadersVisible(), maximumListRows(), limitToList(), displayWidget()
+				if (!schema.setLookupFieldSchema(f->name(), lookupFieldSchema)) {
+					kexipluginswarn << 
+						"KexiTableDesignerView::buildSchema(): !schema.setLookupFieldSchema()" << endl;
+					delete lookupFieldSchema;
+					return false;
+				}
+			}
 		}
 	}
 	return res;
@@ -1350,43 +1427,27 @@ tristate KexiTableDesignerView::storeData(bool dontAsk)
 		return false;
 	}
 
-	tristate res = true;
-	if (!d->tempStoreDataUsingRealAlterTable && !d->dontAskOnStoreData && !dontAsk) {
-		bool emptyTable;
-		const QString msg = d->messageForSavingChanges(emptyTable);
-		if (!emptyTable) {
-			if (KMessageBox::No == KMessageBox::questionYesNo(this, msg))
-				res = cancelled;
-		}
-	}
-	d->dontAskOnStoreData = false; //one-time use
-	if (~res) {
-		d->recentResultOfStoreData = res;
-		return res;
-	}
-//		KMessageBox::information(this, i18n("Saving changes for existing table design is not yet supported."));
-//		cancel = true;
-
 	KexiDB::Connection *conn = mainWin()->project()->dbConnection();
-
 	KexiDB::AlterTableHandler *alterTableHandler = 0;
 	KexiDB::TableSchema *newTable = 0;
-	if (d->tempStoreDataUsingRealAlterTable) {
-		KexiDB::AlterTableHandler::ActionList actions;
-		res = buildAlterTableActions( actions );
-	//todo: result?
+
+	//- create action list for the alter table handler
+	KexiDB::AlterTableHandler::ActionList actions;
+	tristate res = buildAlterTableActions( actions );
+	bool realAlterTableCanBeUsed = false; //!< @todo this is temporary flag before we switch entirely to real alter table
+	if (res == true) {
 		alterTableHandler = new KexiDB::AlterTableHandler( *conn );
 		alterTableHandler->setActions(actions);
-	}
-	else {
-//! @todo temp; remove this:
-		//keep old behaviour
-		newTable = new KexiDB::TableSchema();
-		//copy schema data
-		static_cast<KexiDB::SchemaData&>(*newTable) = static_cast<KexiDB::SchemaData&>(*tempData()->table);
-		res = buildSchema(*newTable);
-		kexipluginsdbg << "KexiTableDesignerView::storeData() : BUILD SCHEMA:" << endl;
-		newTable->debug();
+
+		if (!d->tempStoreDataUsingRealAlterTable) {
+			//only compute requirements
+			KexiDB::AlterTableHandler::ExecutionArguments args;
+			args.onlyComputeRequirements = true;
+			(void)alterTableHandler->execute(tempData()->table->name(), args);
+			res = args.result;
+			if (res == true && 0 == (args.requirements & (0xffff ^ KexiDB::AlterTableHandler::SchemaAlteringRequired)))
+				realAlterTableCanBeUsed = true;
+		}
 	}
 
 	if (res == true) {
@@ -1396,33 +1457,58 @@ tristate KexiTableDesignerView::storeData(bool dontAsk)
 			"but following objects using this table are opened:")
 			.arg(tempData()->table->name()));
 	}
+
 	if (res == true) {
-		if (d->tempStoreDataUsingRealAlterTable) {
-			newTable = alterTableHandler->execute(tempData()->table->name(), res);
+		if (!d->tempStoreDataUsingRealAlterTable && !realAlterTableCanBeUsed) {
+//! @todo temp; remove this case:
+			delete alterTableHandler;
+			alterTableHandler = 0;
+			// - inform about removing the current table and ask for confimation
+			if (!d->dontAskOnStoreData && !dontAsk) {
+				bool emptyTable;
+				const QString msg = d->messageForSavingChanges(emptyTable);
+				if (!emptyTable) {
+					if (KMessageBox::No == KMessageBox::questionYesNo(this, msg))
+						res = cancelled;
+				}
+			}
+			d->dontAskOnStoreData = false; //one-time use
+			if (~res) {
+				d->recentResultOfStoreData = res;
+				return res;
+			}
+			// keep old behaviour:
+			newTable = new KexiDB::TableSchema();
+			// copy the schema data
+			static_cast<KexiDB::SchemaData&>(*newTable) = static_cast<KexiDB::SchemaData&>(*tempData()->table);
+			res = buildSchema(*newTable);
+			kexipluginsdbg << "KexiTableDesignerView::storeData() : BUILD SCHEMA:" << endl;
+			newTable->debug();
+
+			res = conn->alterTable(*tempData()->table, *newTable);
+			if (res != true)
+				parentDialog()->setStatus(conn, "");
+		}
+		else {
+			KexiDB::AlterTableHandler::ExecutionArguments args;
+			newTable = alterTableHandler->execute(tempData()->table->name(), args);
+			res = args.result;
 			kexipluginsdbg << "KexiTableDesignerView::storeData() : ALTER TABLE EXECUTE: " 
 				<< res.toString() << endl;
-			if (!res) {
+			if (true != res) {
 				alterTableHandler->debugError();
 				parentDialog()->setStatus(alterTableHandler, "");
 			}
-//! @todo: result?
-		}
-		else {
-//! @todo temp; remove this:
-			//keep old behaviour
-			res = conn->alterTable(*tempData()->table, *newTable);
-			if (!res)
-				parentDialog()->setStatus(conn, "");
-		}
-		if (res == true) {
-			//change current schema
-			tempData()->table = newTable;
-			tempData()->tableSchemaChangedInPreviousView = true;
-		}
-		else {
-			delete newTable;
 		}
 	}
+	if (res == true) {
+		//change current schema
+		tempData()->table = newTable;
+		tempData()->tableSchemaChangedInPreviousView = true;
+	}
+	else {
+		delete newTable;
+	}
 	delete alterTableHandler;
 	d->recentResultOfStoreData = res;
 	return res;
@@ -1442,11 +1528,15 @@ tristate KexiTableDesignerView::simulateAlterTableExecution(QString *debugTarget
 //todo: result?
 	KexiDB::AlterTableHandler alterTableHandler( *conn );
 	alterTableHandler.setActions(actions);
-
-	if (debugTarget)
-		return alterTableHandler.simulateExecution(tempData()->table->name(), *debugTarget);
-	else
-		return alterTableHandler.execute(tempData()->table->name(), res, /*simulate*/true);
+	KexiDB::AlterTableHandler::ExecutionArguments args;
+	if (debugTarget) {
+		args.debugString = debugTarget;
+	}
+	else {
+		args.simulate = true;
+	}
+	(void)alterTableHandler.execute(tempData()->table->name(), args);
+	return args.result;
 # else
 	return false;
 # endif
@@ -1813,4 +1903,15 @@ void KexiTableDesignerView::changePropertyVisibility(
 	}
 }
 
+void KexiTableDesignerView::propertySetSwitched()
+{
+	KexiDataTable::propertySetSwitched();
+
+	//if (parentDialog()!=parentDialog()->mainWin()->currentDialog())
+	//	return; //this is not the current dialog's view
+	
+	static_cast<KexiTablePart*>(parentDialog()->part())->lookupColumnPage()
+		->assignPropertySet(propertySet());
+}
+
 #include "kexitabledesignerview.moc"
