@@ -133,7 +133,7 @@ class KEXIDATATABLE_EXPORT KexiDataAwareObjectInterface
 		inline bool isSortingEnabled() const { return m_isSortingEnabled; }
 
 		/*! Sets sorting on column \a col, or (when \a col == -1) sets rows unsorted
-		 this will dont work if sorting is disabled with setSortingEnabled() */
+		 this will do not work if sorting is disabled with setSortingEnabled() */
 		virtual void setSorting(int col, bool ascending=true);
 
 		/*! Enables or disables sorting for this object
@@ -286,6 +286,7 @@ class KEXIDATATABLE_EXPORT KexiDataAwareObjectInterface
 		virtual void selectPrevPage(); //!< page up action
 		virtual void selectFirstRow();
 		virtual void selectLastRow();
+		virtual void addNewRecordRequested();
 
 		/*! Clears current selection. Current row and column will be now unspecified:
 		 currentRow(), currentColumn() will return -1, and selectedItem() will return null. */
@@ -649,8 +650,6 @@ class KEXIDATATABLE_EXPORT KexiDataAwareObjectInterface
 		 Implemented if there is more than one row displayed, i.e. currently for KexiTableView. */
 		virtual void updateAllVisibleRowsBelow(int row) { Q_UNUSED( row ); }
 
-		virtual void addNewRecordRequested();
-
 		//! Call this from the subclass. */
 		virtual void focusOutEvent(QFocusEvent* e);
 
@@ -724,7 +723,7 @@ class KEXIDATATABLE_EXPORT KexiDataAwareObjectInterface
 		bool m_emptyRowInsertingEnabled : 1;
 
 		/*! Contains 1 if the object is readOnly, 0 if not; 
-		 otherwise (-1 means "dont know") the 'readOnly' flag from object's 
+		 otherwise (-1 means "do not know") the 'readOnly' flag from object's 
 		 internal data structure (KexiTableViewData *KexiTableView::m_data) is reused. 
 		 */
 		int m_readOnly;
@@ -839,24 +838,19 @@ public: \
 	void connectCellSelectedSignal(const QObject* receiver, const char* intIntMember) { \
 		connect(this, SIGNAL(cellSelected(int,int)), receiver, intIntMember); \
 	} \
-	\
 	void connectRowEditStartedSignal(const QObject* receiver, const char* intMember) { \
 		connect(this, SIGNAL(rowEditStarted(int)), receiver, intMember); \
 	} \
-	\
 	void connectRowEditTerminatedSignal(const QObject* receiver, const char* voidMember) { \
 		connect(this, SIGNAL(rowEditTerminated(int)), receiver, voidMember); \
 	} \
-	\
 	void connectReloadActionsSignal(const QObject* receiver, const char* voidMember) { \
 		connect(this, SIGNAL(reloadActions()), receiver, voidMember); \
 	} \
-	\
 	void connectDataSetSignal(const QObject* receiver, \
 		const char* kexiTableViewDataMember) { \
 		connect(this, SIGNAL(dataSet(KexiTableViewData*)), receiver, kexiTableViewDataMember); \
 	} \
-	\
 	void connectToReloadDataSlot(const QObject* sender, const char* voidSignal) { \
 		connect(sender, voidSignal, this, SLOT(reloadData())); \
 	}
