@@ -14,13 +14,13 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 #ifndef SML_TOOL_CONNECTOR_H
 #define SML_TOOL_CONNECTOR_H
 
 #include "kivio_mousetool.h"
-#include <koPoint.h>
+#include <KoPoint.h>
 
 class QMouseEvent;
 class QCursor;
