@@ -770,16 +770,16 @@ void KisImage::scale(double sx, double sy, KisProgressDisplayInterface *progress
             m_adapter->beginMacro(i18n("Scale Image"));
             m_adapter->addCommand(new LockImageCommand(this, true));
         }
-
-//        if ( colorSpace()->id() == KisID("RGBA") || colorSpace()->id() == KisID("CMYK") || colorSpace()->id() == KisID("GRAYA")) {
-//          KisScaleVisitor v (this, sx, sy, progress, filterStrategy);
-//            m_rootLayer->accept( v );
-//        }
-//        else {
-
+#if 0
+        if ( colorSpace()->id() == KisID("RGBA") || colorSpace()->id() == KisID("CMYK") || colorSpace()->id() == KisID("GRAYA")) {
+            KisScaleVisitor v (this, sx, sy, progress, filterStrategy);
+            m_rootLayer->accept( v );
+        }
+        else {
+#endif
             KisTransformVisitor visitor (this, sx, sy, 0.0, 0.0, 0.0, 0, 0, progress, filterStrategy);
             m_rootLayer->accept(visitor);
-//      }
+//        }
 
         if (undo()) {
             m_adapter->addCommand(new KisResizeImageCmd(m_adapter, this, w, h, width(), height()));
@@ -801,17 +801,16 @@ void KisImage::scale(double sx, double sy, KisProgressDisplayInterface *progress
 
 
 
-void KisImage::rotate(double angle, KisProgressDisplayInterface *progress)
+void KisImage::rotate(double radians, KisProgressDisplayInterface *progress)
 {
     lock();
 
-    angle *= M_PI/180;
     Q_INT32 w = width();
     Q_INT32 h = height();
-    Q_INT32 tx = Q_INT32((w*cos(angle) - h*sin(angle) - w) / 2 + 0.5);
-    Q_INT32 ty = Q_INT32((h*cos(angle) + w*sin(angle) - h) / 2 + 0.5);
-    w = (Q_INT32)(width()*QABS(cos(angle)) + height()*QABS(sin(angle)) + 0.5);
-    h = (Q_INT32)(height()*QABS(cos(angle)) + width()*QABS(sin(angle)) + 0.5);
+    Q_INT32 tx = Q_INT32((w*cos(radians) - h*sin(radians) - w) / 2 + 0.5);
+    Q_INT32 ty = Q_INT32((h*cos(radians) + w*sin(radians) - h) / 2 + 0.5);
+    w = (Q_INT32)(width()*QABS(cos(radians)) + height()*QABS(sin(radians)) + 0.5);
+    h = (Q_INT32)(height()*QABS(cos(radians)) + width()*QABS(sin(radians)) + 0.5);
 
     tx -= (w - width()) / 2;
     ty -= (h - height()) / 2;
@@ -822,7 +821,7 @@ void KisImage::rotate(double angle, KisProgressDisplayInterface *progress)
     }
 
     KisFilterStrategy *filter = KisFilterStrategyRegistry::instance()->get(KisID("Triangle"));
-    KisTransformVisitor visitor (this, 1.0, 1.0, 0, 0, angle, -tx, -ty, progress, filter);
+    KisTransformVisitor visitor (this, 1.0, 1.0, 0, 0, radians, -tx, -ty, progress, filter);
     m_rootLayer->accept(visitor);
 
     if (undo()) m_adapter->addCommand(new KisResizeImageCmd(undoAdapter(), this, w, h, width(), height()));
@@ -1010,7 +1009,6 @@ KisPaintDeviceSP KisImage::activeDevice()
     else if (KisLayerSP layer = m_activeLayer) {
         // A weird layer -- let's not return it, but a sibling
         KisLayerSP sibling = layer->nextSibling();
-        kdDebug() << "sibling: " << sibling->name() << endl;
         while (sibling) {
             if (KisPaintLayer* layer = dynamic_cast<KisPaintLayer*>(sibling.data())) {
                 return layer->paintDevice();
@@ -1432,6 +1430,7 @@ QImage KisImage::convertToQImage(Q_INT32 x1,
 
 QImage KisImage::convertToQImage(const QRect& r, const QSize& scaledImageSize, KisProfile *profile, PaintFlags paintFlags, float exposure)
 {
+
     if (r.isEmpty() || scaledImageSize.isEmpty()) {
         return QImage();
     }
@@ -1451,8 +1450,8 @@ QImage KisImage::convertToQImage(const QRect& r, const QSize& scaledImageSize, K
     srcRect.setBottom(static_cast<int>(ceil((r.bottom() + 1) * yScale)) - 1);
 
     KisPaintDeviceSP mergedImage = m_rootLayer->projection(srcRect);
-    //QTime t;
-    //t.start();
+    QTime t;
+    t.start();
 
     Q_UINT8 *scaledImageData = new Q_UINT8[r.width() * r.height() * pixelSize];
 
@@ -1481,6 +1480,7 @@ QImage KisImage::convertToQImage(const QRect& r, const QSize& scaledImageSize, K
             --columnsRemaining;
         }
     }
+    kdDebug() << "Time elapsed scaling image: " << t.elapsed() << endl;
 
     delete [] imageRow;
 
