@@ -40,6 +40,7 @@
 #include "kis_iteratorpixeltrait.h"
 #include "kis_random_accessor.h"
 #include "kis_random_sub_accessor.h"
+#include "kis_transaction.h"
 #include "kis_profile.h"
 #include "kis_color.h"
 #include "kis_integer_maths.h"
@@ -50,6 +51,7 @@
 #include "kis_paint_device.h"
 #include "kis_datamanager.h"
 #include "kis_memento.h"
+#include "kis_selection.h"
 
 #include "kis_exif_info.h"
 
@@ -200,7 +202,7 @@ namespace {
 }
 
 KisPaintDevice::KisPaintDevice(KisColorSpace * colorSpace, const char * name) :
-        QObject(0, name), KShared(), m_exifInfo(0)
+        QObject(0, name), KShared(), m_exifInfo(0),  m_lock( false )
 {
     if (colorSpace == 0) {
         kdWarning(41001) << "Cannot create paint device without colorstrategy!\n";
@@ -208,7 +210,7 @@ KisPaintDevice::KisPaintDevice(KisColorSpace * colorSpace, const char * name) :
     }
     m_longRunningFilterTimer = 0;
     m_dcop = 0;
-    
+
     m_x = 0;
     m_y = 0;
 
@@ -232,18 +234,12 @@ KisPaintDevice::KisPaintDevice(KisColorSpace * colorSpace, const char * name) :
     m_selectionDeselected = false;
     m_selection = 0;
 
-    m_longRunningFilters = colorSpace->createBackgroundFilters();
-    if (!m_longRunningFilters.isEmpty()) {
-        m_longRunningFilterTimer = new QTimer(this);
-        connect(m_longRunningFilterTimer, SIGNAL(timeout()), this, SLOT(runBackgroundFilters()));
-        m_longRunningFilterTimer->start(800);
-    }
 }
 
 KisPaintDevice::KisPaintDevice(KisLayer *parent, KisColorSpace * colorSpace, const char * name) :
-        QObject(0, name), KShared(), m_exifInfo(0)
+        QObject(0, name), KShared(), m_exifInfo(0), m_lock( false )
 {
-    
+
     m_longRunningFilterTimer = 0;
     m_dcop = 0;
 
@@ -264,7 +260,7 @@ KisPaintDevice::KisPaintDevice(KisLayer *parent, KisColorSpace * colorSpace, con
     }
 
     Q_ASSERT( m_colorSpace );
-    
+
     m_pixelSize = m_colorSpace->pixelSize();
     m_nChannels = m_colorSpace->nChannels();
 
@@ -276,16 +272,18 @@ KisPaintDevice::KisPaintDevice(KisLayer *parent, KisColorSpace * colorSpace, con
     Q_CHECK_PTR(m_datamanager);
     m_extentIsValid = true;
 
-    
-    m_longRunningFilters = m_colorSpace->createBackgroundFilters();
-    if (!m_longRunningFilters.isEmpty()) {
-        m_longRunningFilterTimer = new QTimer(this);
-        connect(m_longRunningFilterTimer, SIGNAL(timeout()), this, SLOT(runBackgroundFilters()));
-        m_longRunningFilterTimer->start(800);
+    if ( QString ( name ) == QString( "Layer 1" ) ) {
+        m_longRunningFilters = m_colorSpace->createBackgroundFilters();
+
+        if (!m_longRunningFilters.isEmpty()) {
+            m_longRunningFilterTimer = new QTimer(this);
+            connect(m_longRunningFilterTimer, SIGNAL(timeout()), this, SLOT(runBackgroundFilters()));
+            m_longRunningFilterTimer->start(2000);
+        }
     }
 }
 
- 
+
 KisPaintDevice::KisPaintDevice(const KisPaintDevice& rhs) : QObject(), KShared(rhs)
 {
     if (this != &rhs) {
@@ -303,8 +301,13 @@ KisPaintDevice::KisPaintDevice(const KisPaintDevice& rhs) : QObject(), KShared(r
         m_x = rhs.m_x;
         m_y = rhs.m_y;
         m_colorSpace = rhs.m_colorSpace;
-        m_hasSelection = false;
-        m_selection = 0;
+        m_hasSelection = rhs.m_hasSelection;
+
+        if  ( m_hasSelection )
+            m_selection = new KisSelection(*rhs.m_selection);
+        else
+            m_selection = 0;
+
         m_pixelSize = rhs.m_pixelSize;
         m_nChannels = rhs.m_nChannels;
         if(rhs.m_exifInfo)
@@ -520,7 +523,7 @@ QRect KisPaintDevice::exactBoundsImprovedOldMethod() const
     Q_INT32  x, y, w, h, boundX2, boundY2, boundW2, boundH2;
     extent(x, y, w, h);
     extent(boundX2, boundY2, boundW2, boundH2);
-    
+
     const Q_UINT8* defaultPixel = m_datamanager->defaultPixel();
     bool found = false;
     {
@@ -600,12 +603,7 @@ QRect KisPaintDevice::exactBoundsImprovedOldMethod() const
 
 QRect KisPaintDevice::exactBounds() const
 {
-    QRect r1 = exactBoundsOldMethod();
     QRect r2 = exactBoundsImprovedOldMethod();
-    if(r1 != r2)
-    {
-        kdDebug() << "EXACTBOUNDSERROR : " << r1 << " " << r2 << endl;
-    }
     return r2;
 }
 
@@ -634,7 +632,7 @@ void KisPaintDevice::mirrorX()
 {
     QRect r;
     if (hasSelection()) {
-        r = selection()->exactBounds();
+        r = selection()->selectedRect();
     }
     else {
         r = exactBounds();
@@ -665,7 +663,7 @@ void KisPaintDevice::mirrorY()
     /* Read a line from bottom to top and and from top to bottom and write their values to each other */
     QRect r;
     if (hasSelection()) {
-        r = selection()->exactBounds();
+        r = selection()->selectedRect();
     }
     else {
         r = exactBounds();
@@ -1075,7 +1073,7 @@ void KisPaintDevice::subtractSelection(KisSelectionSP selection) {
 
     QRect r = selection->selectedExactRect();
     painter.bitBlt(r.x(), r.y(), COMPOSITE_ERASE, selection.data(), r.x(), r.y(), r.width(), r.height());
-    
+
     selection->invert();
     painter.end();
 }
@@ -1111,7 +1109,7 @@ void KisPaintDevice::clearSelection()
 
 void KisPaintDevice::applySelectionMask(KisSelectionSP mask)
 {
-    QRect r = mask->extent();
+    QRect r = mask->selectedRect();
     crop(r);
 
     for (Q_INT32 y = r.top(); y <= r.bottom(); ++y) {
@@ -1267,6 +1265,10 @@ KisExifInfo* KisPaintDevice::exifInfo()
 
 void KisPaintDevice::runBackgroundFilters()
 {
+    if ( m_lock ) return;
+
+    KisTransaction * cmd = new KisTransaction("Running autofilters", this);
+
     QRect rc = extent();
     if (!m_longRunningFilters.isEmpty()) {
         QValueList<KisFilter*>::iterator it;
@@ -1275,6 +1277,8 @@ void KisPaintDevice::runBackgroundFilters()
             (*it)->process(this, this, 0, rc);
         }
     }
+    if (cmd && undoAdapter()) undoAdapter()->addCommand(cmd);
+
     if (m_parentLayer) m_parentLayer->setDirty(rc);
 }
 
