@@ -28,6 +28,7 @@
 #include "kis_iterators_pixel.h"
 #include "kis_filter_strategy.h"
 #include "kis_layer.h"
+#include "kis_painter.h"
 
 KisTransformWorker::KisTransformWorker(KisPaintDeviceSP dev, double xscale, double yscale,
                     double xshear, double yshear, double rotation,
@@ -46,6 +47,57 @@ KisTransformWorker::KisTransformWorker(KisPaintDeviceSP dev, double xscale, doub
     m_filter = filter;
 }
 
+void KisTransformWorker::rotateNone(KisPaintDeviceSP src, KisPaintDeviceSP dst)
+{
+    KisSelectionSP dstSelection;
+    Q_INT32 pixelSize = src->pixelSize();
+    QRect r;
+    KisColorSpace *cs = src->colorSpace();
+
+    if(src->hasSelection())
+    {
+        r = src->selection()->selectedExactRect();
+        dstSelection = dst->selection();
+    }
+    else
+    {
+        r = src->exactBounds();
+        dstSelection = new KisSelection(dst); // essentially a dummy to be deleted
+    }
+
+    KisHLineIteratorPixel hit = src->createHLineIterator(r.x(), r.top(), r.width(), true);
+    KisHLineIterator vit = dst->createHLineIterator(r.x(), r.top(), r.width(), true);
+    KisHLineIterator dstSelIt = dstSelection->createHLineIterator(r.x(), r.top(), r.width(), true);
+    for (Q_INT32 i = 0; i < r.height(); ++i) {
+            while (!hit.isDone()) {
+            if (hit.isSelected())  {
+                memcpy(vit.rawData(), hit.rawData(), pixelSize);
+
+                // XXX: Should set alpha = alpha*(1-selectedness)
+                cs->setAlpha(hit.rawData(), 0, 1);
+            }
+            *(dstSelIt.rawData()) = hit.selectedness();
+            ++hit;
+            ++vit;
+            ++dstSelIt;
+        }
+        hit.nextRow();
+        vit.nextRow();
+        dstSelIt.nextRow();
+
+        //progress info
+        m_progressStep += r.width();
+        if(m_lastProgressReport != (m_progressStep * 100) / m_progressTotalSteps)
+        {
+            m_lastProgressReport = (m_progressStep * 100) / m_progressTotalSteps;
+            emit notifyProgress(m_lastProgressReport);
+        }
+        if (m_cancelRequested) {
+            break;
+        }
+    }
+}
+
 void KisTransformWorker::rotateRight90(KisPaintDeviceSP src, KisPaintDeviceSP dst)
 {
     KisSelectionSP dstSelection;
@@ -81,6 +133,17 @@ void KisTransformWorker::rotateRight90(KisPaintDeviceSP src, KisPaintDeviceSP ds
             ++vit;
             ++dstSelIt;
         }
+
+        //progress info
+        m_progressStep += r.width();
+        if(m_lastProgressReport != (m_progressStep * 100) / m_progressTotalSteps)
+        {
+            m_lastProgressReport = (m_progressStep * 100) / m_progressTotalSteps;
+            emit notifyProgress(m_lastProgressReport);
+        }
+        if (m_cancelRequested) {
+            break;
+        }
     }
 }
 
@@ -124,11 +187,23 @@ void KisTransformWorker::rotateLeft90(KisPaintDeviceSP src, KisPaintDeviceSP dst
             ++dstSelIt;
         }
         ++x;
+
+        //progress info
+        m_progressStep += r.width();
+        if(m_lastProgressReport != (m_progressStep * 100) / m_progressTotalSteps)
+        {
+            m_lastProgressReport = (m_progressStep * 100) / m_progressTotalSteps;
+            emit notifyProgress(m_lastProgressReport);
+        }
+        if (m_cancelRequested) {
+            break;
+        }
     }
 }
 
 void KisTransformWorker::rotate180(KisPaintDeviceSP src, KisPaintDeviceSP dst)
 {
+    kdDebug() << "Rotating 180\n";
     KisSelectionSP dstSelection;
     Q_INT32 pixelSize = src->pixelSize();
     QRect r;
@@ -163,6 +238,17 @@ void KisTransformWorker::rotate180(KisPaintDeviceSP src, KisPaintDeviceSP dst)
             ++dstIt;
             ++dstSelIt;
         }
+
+        //progress info
+        m_progressStep += r.width();
+        if(m_lastProgressReport != (m_progressStep * 100) / m_progressTotalSteps)
+        {
+            m_lastProgressReport = (m_progressStep * 100) / m_progressTotalSteps;
+            emit notifyProgress(m_lastProgressReport);
+        }
+        if (m_cancelRequested) {
+            break;
+        }
     }
 }
 
@@ -470,44 +556,87 @@ bool KisTransformWorker::run()
         rotation = fmod(rotation, 2*M_PI);
     int rotQuadrant = int(rotation /(M_PI/2) + 0.5) & 3;
 
+    // Figure out how we will do the initial right angle rotations
     double tmp;
     switch(rotQuadrant)
     {
+        default: // just to shut up the compiler
+        case 0:
+            m_progressTotalSteps = 0;
+            break;
+        case 1:
+            rotation -= M_PI/2;
+            tmp = xscale;
+            xscale=yscale;
+            yscale=tmp;
+            m_progressTotalSteps = r.width() * r.height();
+            break;
+        case 2:
+            rotation -= M_PI;
+            m_progressTotalSteps = r.width() * r.height();
+            break;
+        case 3:
+            rotation -= -M_PI/2 + 2*M_PI;
+            tmp = xscale;
+            xscale = yscale;
+            yscale = tmp;
+            m_progressTotalSteps = r.width() * r.height();
+            break;
+    }
+
+    // Calculate some auxillary values
+    yshear = sin(rotation);
+    xshear = -tan(rotation/2);
+    xtranslate -= int(xshear*ytranslate);
+
+    // Calculate progress steps
+    m_progressTotalSteps += int(yscale * r.width() * r.height());
+    m_progressTotalSteps += int(xscale * r.width() * (r.height() * yscale + r.width()*yshear));
+
+    m_lastProgressReport=0;
+
+    // Now that we have everything in place it's time to do the actual right angle rotations
+    switch(rotQuadrant)
+    {
+        default: // just to shut up the compiler
         case 0:
             break;
         case 1:
             rotateRight90(srcdev, tmpdev1);
             srcdev = tmpdev1;
-            rotation -= M_PI/2;
-            tmp = xscale;
-            xscale=yscale;
-            yscale=tmp;
             break;
         case 2:
             rotate180(srcdev, tmpdev1);
             srcdev = tmpdev1;
-            rotation -= M_PI;
             break;
         case 3:
             rotateLeft90(srcdev, tmpdev1);
             srcdev = tmpdev1;
-            rotation += M_PI/2 + 2*M_PI;
-            tmp = xscale;
-            xscale = yscale;
-            yscale = tmp;
-            break;
-        default:
             break;
     }
 
-    yshear = sin(rotation);
-    xshear = -tan(rotation/2);
-    xtranslate -= int(xshear*ytranslate);
+    // Handle simple move case possibly with rotation of 90,180,270
+    if(rotation == 0.0 && xscale == 1.0 && yscale == 1.0)
+    {
+        if(rotQuadrant==0)
+        {
+            // Though not nessesay in the general case because we make several passes
+            // We need to move (not just copy) the data to a temp dev so we can move them back
+            rotateNone(srcdev, tmpdev1);
+            srcdev = tmpdev1;
+        }
+        if(m_dev->hasSelection())
+            m_dev->selection()->clear();
 
-    m_progressTotalSteps = int(yscale * r.width() * r.height());
-    m_progressTotalSteps += int(xscale * r.width() * (r.height() * yscale + r.width()*yshear));
+        srcdev->move(srcdev->getX() + xtranslate, srcdev->getY() + ytranslate);
+        rotateNone(srcdev, m_dev);
 
-    m_lastProgressReport=0;
+        //progress info
+        emit notifyProgressDone();
+        m_dev->emitSelectionChanged();
+
+        return m_cancelRequested;
+    }
 
     if ( m_cancelRequested) {
         emit notifyProgressDone();
@@ -523,11 +652,8 @@ bool KisTransformWorker::run()
         return false;
     }
 
-    if(xshear==0.0)
-        // Not going to do the third transform when scaling
-        transformPass <KisVLineIteratorPixel>(tmpdev2.data(), m_dev.data(), yscale, yshear, ytranslate, m_filter);
-    else
-        transformPass <KisVLineIteratorPixel>(tmpdev2.data(), tmpdev3.data(), yscale, yshear, ytranslate, m_filter);
+    // Now do the second pass
+    transformPass <KisVLineIteratorPixel>(tmpdev2.data(), tmpdev3.data(), yscale, yshear, ytranslate, m_filter);
 
     if(m_dev->hasSelection())
         m_dev->selection()->clear();
@@ -539,6 +665,13 @@ bool KisTransformWorker::run()
 
     if (xshear != 0.0)
         transformPass <KisHLineIteratorPixel>(tmpdev3, m_dev, 1.0, xshear, xtranslate, m_filter);
+    else
+    {
+        // No need to filter again when we are only scaling
+        tmpdev3->move(tmpdev3->getX() + xtranslate, tmpdev3->getY());
+        rotateNone(tmpdev3, m_dev);
+    }
+
     if (m_dev->parentLayer()) {
         m_dev->parentLayer()->setDirty();
     }
