@@ -53,9 +53,10 @@ KisTile::KisTile(const KisTile& rhs, Q_INT32 col, Q_INT32 row)
 
         allocate();
 
-        if (rhs.m_data) {
-            memcpy(m_data, rhs.m_data, WIDTH * HEIGHT * m_pixelSize * sizeof(Q_UINT8));
-        }
+        // Assure we have data to copy
+        rhs.addReader();
+        memcpy(m_data, rhs.m_data, WIDTH * HEIGHT * m_pixelSize * sizeof(Q_UINT8));
+        rhs.removeReader();
 
         m_col = col;
         m_row = row;
@@ -76,9 +77,9 @@ KisTile::KisTile(const KisTile& rhs)
 
         allocate();
 
-        if (rhs.m_data) {
-            memcpy(m_data, rhs.m_data, WIDTH * HEIGHT * m_pixelSize * sizeof(Q_UINT8));
-        }
+        rhs.addReader();
+        memcpy(m_data, rhs.m_data, WIDTH * HEIGHT * m_pixelSize * sizeof(Q_UINT8));
+        rhs.removeReader();
 
         KisTileManager::instance()->registerTile(this);
     }
@@ -112,7 +113,10 @@ void KisTile::setNext(KisTile *n)
 
 Q_UINT8 *KisTile::data(Q_INT32 x, Q_INT32 y ) const
 {
-    //Q_ASSERT(m_data != 0);
+    addReader();
+    removeReader();
+
+    Q_ASSERT(m_data != 0);
     if (m_data == 0) return 0;
 
     return m_data + m_pixelSize * ( y * WIDTH + x );
@@ -120,9 +124,8 @@ Q_UINT8 *KisTile::data(Q_INT32 x, Q_INT32 y ) const
 
 void KisTile::setData(const Q_UINT8 *pixel)
 {
-    Q_UINT8 *dst = m_data;
-
     addReader();
+    Q_UINT8 *dst = m_data;
     for(int i=0; i <WIDTH * HEIGHT;i++)
     {
         memcpy(dst, pixel, m_pixelSize);
@@ -131,7 +134,7 @@ void KisTile::setData(const Q_UINT8 *pixel)
     removeReader();
 }
 
-void KisTile::addReader()
+void KisTile::addReader() const
 {
     if (m_nReadlock++ == 0)
         KisTileManager::instance()->ensureTileLoaded(this);
@@ -139,9 +142,10 @@ void KisTile::addReader()
         kdDebug(41000) << m_nReadlock << endl;
         assert(0);
     }
+    assert(m_data);
 }
 
-void KisTile::removeReader()
+void KisTile::removeReader() const
 {
     if (--m_nReadlock == 0)
         KisTileManager::instance()->maySwapTile(this);
