@@ -55,6 +55,7 @@ KisFilterManager::KisFilterManager(KisView * view, KisDoc * doc)
     : m_view(view),
     m_doc(doc)
 {
+    connect(&m_delayer, SIGNAL(timeout()), this, SLOT(refreshPreview()));
     // XXX: Store & restore last filter & last filter configuration in session settings
     m_reapplyAction = 0;
     m_lastFilterConfig = 0;
@@ -145,7 +146,7 @@ void KisFilterManager::setup(KActionCollection * ac)
 
         else if (s == "other" && !m_filterActionMenus.find("other")) {
             other = new KActionMenu(i18n("Other"), ac, "misc_filters");
-            m_filterActionMenus.insert("other", am);
+            m_filterActionMenus.insert("other", other);
         }
 
     }
@@ -276,7 +277,6 @@ bool KisFilterManager::apply()
 
     if (m_lastFilter->cancelRequested()) {
         delete m_lastFilterConfig;
-        m_lastFilterConfig = 0;
         if (cmd) {
             cmd->unexecute();
             delete cmd;
@@ -372,6 +372,7 @@ void KisFilterManager::slotApplyFilter(int i)
     }
 
     if (!apply()) {
+        delete m_lastDialog;
         m_lastFilterConfig = oldConfig;
         m_lastDialog = oldDialog;
         m_lastFilter = oldFilter;
@@ -385,7 +386,8 @@ void KisFilterManager::slotConfigChanged()
         return;
     if(m_lastDialog->previewWidget()->getAutoUpdate())
     {
-        refreshPreview();
+//         refreshPreview();
+      m_delayer.start(1000, true);
     } else {
         m_lastDialog->previewWidget()->needUpdate();
     }
