@@ -1,7 +1,7 @@
 
 /*
 
- $Id: configdlg.h,v 1.5 2003/03/07 22:05:55 waba Exp $
+ $Id: configdlg.h 466447 2005-10-02 17:54:10Z zander $
 
 
  KCalc
@@ -22,7 +22,8 @@
 
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
- Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
 
  */
 
@@ -104,7 +105,7 @@ private:
   QLabel *stylelabel;
   QRadioButton *trigstyle;
   QRadioButton *statstyle;
-  QRadioButton *tablestyle;
+  QRadioButton *sheetstyle;
 };
 #endif
 
