@@ -79,7 +79,10 @@ public:
      * Calculates our width and height and
      * our children's parentPosition.
      */
-    virtual void calcSizes(const ContextStyle& context, ContextStyle::TextStyle tstyle, ContextStyle::IndexStyle istyle);
+    virtual void calcSizes( const ContextStyle& style,
+						    ContextStyle::TextStyle tstyle,
+						    ContextStyle::IndexStyle istyle,
+							StyleAttributes& style );
 
     /**
      * Draws the whole element including its children.
@@ -90,6 +93,7 @@ public:
                        const ContextStyle& context,
                        ContextStyle::TextStyle tstyle,
                        ContextStyle::IndexStyle istyle,
+					   StyleAttributes& style,
                        const LuPixelPoint& parentOrigin );
 
     /**
@@ -262,8 +266,6 @@ public:
     // the upper right index is the only one we show
     virtual QString formulaString();
 
-    virtual void writeMathML( QDomDocument& doc, QDomNode& parent, bool oasisFormat = false );
-
 protected:
 
     //Save/load support
@@ -278,6 +280,11 @@ protected:
      */
     virtual void writeDom(QDomElement element);
 
+    virtual QString getElementName() const ;
+    virtual void writeMathMLAttributes( QDomElement& element ) const ;
+    virtual void writeMathMLContent( QDomDocument& doc, 
+                                     QDomElement& element,
+                                     bool oasisFormat ) const ;
     /**
      * Reads our attributes from the element.
      * Returns false if it failed.
@@ -291,6 +298,15 @@ protected:
      */
     virtual bool readContentFromDom(QDomNode& node);
 
+    virtual bool readAttributesFromMathMLDom( const QDomElement& element );
+    /**
+     * Reads our content from the MathML node. Sets the node to the next node
+     * that needs to be read. It is sometimes needed to read more than one node
+     * (e. g. for fence operators).
+     * Returns the number of nodes processed or -1 if it failed.
+     */
+    virtual int readContentFromMathMLDom( QDomNode& node );
+
 private:
 
     /**
@@ -407,6 +423,18 @@ private:
     SequenceElement* lowerLeft;
     SequenceElement* lowerMiddle;
     SequenceElement* lowerRight;
+
+    /**
+     * MathML attributes.
+     */
+    SizeType m_subScriptShiftType;
+    double m_subScriptShift;
+    SizeType m_superScriptShiftType;
+    double m_superScriptShift;
+    bool m_accentUnder;
+    bool m_customAccentUnder;
+    bool m_accent;
+    bool m_customAccent;
 };
 
 KFORMULA_NAMESPACE_END
