@@ -524,6 +524,8 @@ QValueList<KoVariable *> KoVariableCollection::recalcVariables(int type)
         {
             QVariant oldValue = variable->varValue();
             variable->recalc();
+            if(variable->height == 0)
+                variable->resize();
             if ( variable->varValue() != oldValue )
                 modifiedVariables.append( variable );
             KoTextParag * parag = variable->paragraph();
